@@ -2,9 +2,13 @@
 
 __author__ = "Greg Caporaso"
 __copyright__ = "Copyright 2011, The QIIME Project"
-__credits__ = ["Rob Knight", "Greg Caporaso", "Jeremy Widmann", "Kyle Bittinger"]
+__credits__ = [
+    "Rob Knight",
+    "Greg Caporaso",
+    "Jeremy Widmann",
+    "Kyle Bittinger"]
 __license__ = "GPL"
-__version__ = "1.8.0"
+__version__ = "1.9.1"
 __maintainer__ = "Greg Caporaso"
 __email__ = "gregcaporaso@gmail.com"
 
@@ -12,7 +16,7 @@ __email__ = "gregcaporaso@gmail.com"
 """Contains code for aligning sequences, using several techniques.
 
 This module has the responsibility for taking a set of sequences and
-returning an alignment. Mostly, it will be thin wrappers for code 
+returning an alignment. Mostly, it will be thin wrappers for code
 already in cogent.app.*, to which wrappers for e.g. PyNAST need to be
 added..
 """
@@ -20,22 +24,24 @@ import warnings
 warnings.filterwarnings('ignore', 'Not using MPI as mpi4py not found')
 from os import remove
 from numpy import median
-from cogent import LoadSeqs, DNA
-from cogent.core.alignment import DenseAlignment, SequenceCollection, Alignment
-from cogent.core.sequence import DnaSequence as Dna
-from cogent.parse.fasta import MinimalFastaParser
-from cogent.parse.record import RecordError
-from cogent.app.util import ApplicationNotFoundError
-from cogent.app.infernal import cmalign_from_alignment
+
+import bfillings
+from bfillings.infernal import cmalign_from_alignment
+import bfillings.clustalw
+import bfillings.muscle_v38
+import bfillings.mafft
+
 from cogent.parse.rfam import MinimalRfamParser, ChangedSequence
-import cogent.app.clustalw
-import cogent.app.mafft
+from burrito.util import ApplicationNotFoundError
+from skbio.io import RecordError
+from skbio.parse.sequences import parse_fasta
 
-from qiime.util import (get_tmp_filename,
-                        FunctionWithParams,
+from qiime.util import (FunctionWithParams,
                         get_qiime_temp_dir)
-import cogent.app.muscle_v38
 
+from skbio.alignment import SequenceCollection, Alignment
+from skbio.sequence import DNASequence
+from skbio.parse.sequences import parse_fasta
 
 # Load PyNAST if it's available. If it's not, skip it if not but set up
 # to raise errors if the user tries to use it.
@@ -45,15 +51,15 @@ try:
 
 except ImportError:
     def raise_pynast_not_found_error(*args, **kwargs):
-        raise ApplicationNotFoundError,\
-         "PyNAST cannot be found.\nIs PyNAST installed? Is it in your $PYTHONPATH?"+\
-         "\nYou can obtain PyNAST from http://qiime.org/pynast/."
+        raise ApplicationNotFoundError("PyNAST cannot be found.\nIs PyNAST installed? Is it in your $PYTHONPATH?" +
+                                       "\nYou can obtain PyNAST from http://qiime.org/pynast/.")
     # set functions which cannot be imported to raise_pynast_not_found_error
     pynast_seqs = NastLogger = raise_pynast_not_found_error
     pairwise_alignment_methods = {}
 
 
 class Aligner(FunctionWithParams):
+
     """An Aligner takes an unaligned set of sequences and returns an alignment.
 
     This is an abstract class: subclasses should implement the __call__
@@ -67,9 +73,9 @@ class Aligner(FunctionWithParams):
 
     def __init__(self, params):
         """Return new Aligner object with specified params.
-        
+
         Note: expect params to contain both generic and per-method (e.g. for
-        infernal vs. PyNAST vs. whatever) params, so leaving it as a dict 
+        infernal vs. PyNAST vs. whatever) params, so leaving it as a dict
         rather than setting attributes. Some standard entries in params are:
 
         Application: 3rd-party application used, if any, e.g. infernal
@@ -78,26 +84,28 @@ class Aligner(FunctionWithParams):
         """
         self.Params = params
 
-    def __call__ (self, seq_path, result_path=None, log_path=None):
+    def __call__(self, seq_path, result_path=None, log_path=None):
         """Returns alignment from sequences.
-        
+
         Parameters:
         seq_path: path to file of sequences
         result_path: path to file of results. If specified, should
         dump the result to the desired path as fasta, otherwise should
-        return cogent.core.alignment.DenseAlignment object.
+        return skbio.core.alignment.Alignment object.
         log_path: path to log, which should include dump of params.
         """
-        raise NotImplementedError, "Aligner is an abstract class"
+        raise NotImplementedError("Aligner is an abstract class")
+
 
 class CogentAligner(Aligner):
+
     """Generic aligner using Cogent multiple alignment methods."""
 
     Name = 'CogentAligner'
 
     def getResult(self, seq_path):
         """Returns alignment from sequences.
-        
+
         By convention, app parameters begin with a '-'.  Key-value
         pairs in self.Params following this convention will be passed
         as parameters to the module's alignment function.
@@ -106,14 +114,15 @@ class CogentAligner(Aligner):
         seqs = self.getData(seq_path)
         params = dict(
             [(k, v) for (k, v) in self.Params.items() if k.startswith('-')])
-        result = module.align_unaligned_seqs(seqs, moltype=DNA, params=params)
+        result = module.align_unaligned_seqs(seqs, params=params)
         return result
 
     def __call__(self, result_path=None, log_path=None, *args, **kwargs):
         """Calls superclass method to align seqs"""
         return FunctionWithParams.__call__(self, result_path=result_path,
-            log_path=log_path, *args, **kwargs)
-            
+                                           log_path=log_path, *args, **kwargs)
+
+
 class InfernalAligner(Aligner):
     Name = 'InfernalAligner'
 
@@ -121,82 +130,83 @@ class InfernalAligner(Aligner):
         """Return new InfernalAligner object with specified params.
         """
         _params = {
-            'moltype': DNA,
             'Application': 'Infernal',
-            }
+        }
         _params.update(params)
         Aligner.__init__(self, _params)
 
-    def __call__(self, seq_path, result_path=None, log_path=None, \
-        failure_path=None, cmbuild_params=None, cmalign_params=None):
-        
+    def __call__(self, seq_path, result_path=None, log_path=None,
+                 failure_path=None, cmbuild_params=None, cmalign_params=None):
+
         log_params = []
         # load candidate sequences
-        candidate_sequences = dict(MinimalFastaParser(open(seq_path,'U')))
-        
+        candidate_sequences = dict(parse_fasta(open(seq_path, 'U')))
+
         # load template sequences
         try:
-            info, template_alignment, struct = list(MinimalRfamParser(open(\
-                self.Params['template_filepath'],'U'),\
+            info, template_alignment, struct = list(MinimalRfamParser(open(
+                self.Params['template_filepath'], 'U'),
                 seq_constructor=ChangedSequence))[0]
         except RecordError:
-            raise ValueError, "Template alignment must be in Stockholm format with corresponding secondary structure annotation when using InfernalAligner."
-        
-        moltype = self.Params['moltype']
-        
-        #Need to make separate mapping for unaligned sequences
-        unaligned = SequenceCollection(candidate_sequences,MolType=moltype)
-        int_map, int_keys = unaligned.getIntMap(prefix='unaligned_')
-        int_map = SequenceCollection(int_map,MolType=moltype)
-        
-        #Turn on --gapthresh option in cmbuild to force alignment to full model
+            raise ValueError(
+                "Template alignment must be in Stockholm format with corresponding secondary structure annotation when using InfernalAligner.")
+
+        # Need to make separate mapping for unaligned sequences
+        unaligned = SequenceCollection.from_fasta_records(
+            candidate_sequences.iteritems(), DNASequence)
+        mapped_seqs, new_to_old_ids = unaligned.int_map(prefix='unaligned_')
+        mapped_seq_tuples = [(k, str(v)) for k,v in mapped_seqs.iteritems()]
+
+        # Turn on --gapthresh option in cmbuild to force alignment to full
+        # model
         if cmbuild_params is None:
             cmbuild_params = {}
-        cmbuild_params.update({'--gapthresh':1.0})
-        
-        #record cmbuild parameters
+        cmbuild_params.update({'--gapthresh': 1.0})
+
+        # record cmbuild parameters
         log_params.append('cmbuild parameters:')
         log_params.append(str(cmbuild_params))
-        
-        #Turn on --sub option in Infernal, since we know the unaligned sequences
+
+        # Turn on --sub option in Infernal, since we know the unaligned sequences
         # are fragments.
-        #Also turn on --gapthresh to use same gapthresh as was used to build
+        # Also turn on --gapthresh to use same gapthresh as was used to build
         # model
-        
         if cmalign_params is None:
             cmalign_params = {}
-        cmalign_params.update({'--sub':True,'--gapthresh':1.0})
-        
-        #record cmalign parameters
+        cmalign_params.update({'--sub': True, '--gapthresh': 1.0})
+
+        # record cmalign parameters
         log_params.append('cmalign parameters:')
         log_params.append(str(cmalign_params))
-        
-        #Align sequences to alignment including alignment gaps.
-        aligned, struct_string = cmalign_from_alignment(aln=template_alignment,\
-            structure_string=struct,\
-            seqs=int_map,\
-            moltype=moltype,\
-            include_aln=True,\
-            params=cmalign_params,\
-            cmbuild_params=cmbuild_params)
-        
-        #Pull out original sequences from full alignment.
-        infernal_aligned={}
+
+        # Align sequences to alignment including alignment gaps.
+        aligned, struct_string = cmalign_from_alignment(aln=template_alignment,
+                                                        structure_string=struct,
+                                                        seqs=mapped_seq_tuples,
+                                                        include_aln=True,
+                                                        params=cmalign_params,
+                                                        cmbuild_params=cmbuild_params)
+
+        # Pull out original sequences from full alignment.
+        infernal_aligned = []
+        # Get a dict of the ids to sequences (note that this is a
+        # cogent alignment object, hence the call to NamedSeqs)
         aligned_dict = aligned.NamedSeqs
-        for key in int_map.Names:
-            infernal_aligned[int_keys.get(key,key)]=aligned_dict[key]
-        
-        #Create an Alignment object from alignment dict
-        infernal_aligned = Alignment(infernal_aligned,MolType=moltype)
-        
+        for n, o in new_to_old_ids.iteritems():
+            aligned_seq = aligned_dict[n]
+            infernal_aligned.append((o, aligned_seq))
+
+        # Create an Alignment object from alignment dict
+        infernal_aligned = Alignment.from_fasta_records(infernal_aligned, DNASequence)
+
         if log_path is not None:
-            log_file = open(log_path,'w')
+            log_file = open(log_path, 'w')
             log_file.write('\n'.join(log_params))
             log_file.close()
-        
+
         if result_path is not None:
-            result_file = open(result_path,'w')
-            result_file.write(infernal_aligned.toFasta())
+            result_file = open(result_path, 'w')
+            result_file.write(infernal_aligned.to_fasta())
             result_file.close()
             return None
         else:
@@ -220,29 +230,24 @@ class PyNastAligner(Aligner):
             'pairwise_alignment_method': 'blast',
             'Application': 'PyNAST',
             'Algorithm': 'NAST',
-            }
+        }
         _params.update(params)
         Aligner.__init__(self, _params)
 
-    def __call__(self, seq_path, result_path=None, log_path=None, 
+    def __call__(self, seq_path, result_path=None, log_path=None,
                  failure_path=None):
         # load candidate sequences
         seq_file = open(seq_path, 'U')
-        candidate_sequences = MinimalFastaParser(seq_file)
+        candidate_sequences = parse_fasta(seq_file)
 
         # load template sequences
         template_alignment = []
         template_alignment_fp = self.Params['template_filepath']
-        for seq_id, seq in MinimalFastaParser(open(template_alignment_fp)):
+        for seq_id, seq in parse_fasta(open(template_alignment_fp)):
             # replace '.' characters with '-' characters
-            template_alignment.append((seq_id,seq.replace('.','-').upper()))        
-        try:
-            template_alignment = LoadSeqs(data=template_alignment,moltype=DNA,\
-             aligned=DenseAlignment)
-        except KeyError, e:
-            raise KeyError,\
-             'Only ACGT-. characters can be contained in template alignments.'+\
-             ' The offending character was: %s' % e
+            template_alignment.append((seq_id, seq.replace('.', '-').upper()))
+        template_alignment = Alignment.from_fasta_records(
+                    template_alignment, DNASequence, validate=True)
 
         # initialize_logger
         logger = NastLogger(log_path)
@@ -262,38 +267,42 @@ class PyNastAligner(Aligner):
 
         logger.record(str(self))
 
+        for i, seq in enumerate(pynast_failed):
+            skb_seq = DNASequence(str(seq), id=seq.Name)
+            pynast_failed[i] = skb_seq
+        pynast_failed = SequenceCollection(pynast_failed)
+
+        for i, seq in enumerate(pynast_aligned):
+            skb_seq = DNASequence(str(seq), id=seq.Name)
+            pynast_aligned[i] = skb_seq
+        pynast_aligned = Alignment(pynast_aligned)
+
         if failure_path is not None:
-            fail_file = open(failure_path,'w')
-            for seq in pynast_failed:
-                fail_file.write(seq.toFasta())
-                fail_file.write('\n')
+            fail_file = open(failure_path, 'w')
+            fail_file.write(pynast_failed.to_fasta())
             fail_file.close()
 
         if result_path is not None:
-            result_file = open(result_path,'w')
-            for seq in pynast_aligned:
-                result_file.write(seq.toFasta())
-                result_file.write('\n')
+            result_file = open(result_path, 'w')
+            result_file.write(pynast_aligned.to_fasta())
             result_file.close()
             return None
         else:
-            try:
-                return LoadSeqs(data=pynast_aligned,aligned=DenseAlignment)
-            except ValueError:
-                return {}
+            return pynast_aligned
 
-def compute_min_alignment_length(seqs_f,fraction=0.75):
+
+def compute_min_alignment_length(seqs_f, fraction=0.75):
     """ compute the min alignment length as n standard deviations below the mean """
-    med_length = median([len(s) for _,s in MinimalFastaParser(seqs_f)])
+    med_length = median([len(s) for _, s in parse_fasta(seqs_f)])
     return int(med_length * fraction)
 
 
-alignment_method_constructors ={'pynast':PyNastAligner,\
-    'infernal':InfernalAligner}
+alignment_method_constructors = {'pynast': PyNastAligner,
+                                 'infernal': InfernalAligner}
 
 alignment_module_names = {
-    'muscle': cogent.app.muscle_v38,
-    'clustalw': cogent.app.clustalw,
-    'mafft': cogent.app.mafft,
-    'infernal': cogent.app.infernal,
-    }
+    'muscle': bfillings.muscle_v38,
+    'clustalw': bfillings.clustalw,
+    'mafft': bfillings.mafft,
+    'infernal': bfillings.infernal,
+}
