@@ -6,7 +6,7 @@ __author__ = "Justin Kuczynski"
 __copyright__ = "Copyright 2011, The QIIME Project"
 __credits__ = ["Justin Kuczynski"]
 __license__ = "GPL"
-__version__ = "1.8.0"
+__version__ = "1.9.1"
 __maintainer__ = "Justin Kuczynski"
 __email__ = "justinak@gmail.com"
 
@@ -16,7 +16,7 @@ from qiime.filter import get_sample_ids
 import numpy
 
 
-def get_avg_dists(state1_samids,state2_samids,distdict):
+def get_avg_dists(state1_samids, state2_samids, distdict):
     """ foreach sample in stat1_sams, return average dist to all state2_sams
 
     doesn't include distance to self in average, but usually state2 doesn't
@@ -28,15 +28,17 @@ def get_avg_dists(state1_samids,state2_samids,distdict):
     for sam1 in state1_samids:
         dists = []
         for sam2 in state2_samids:
-            if sam1 == sam2: continue
+            if sam1 == sam2:
+                continue
             dists.append(distdict[sam1][sam2])
         state1_avg_dists.append(numpy.mean(dists))
     return state1_avg_dists
 
-def get_sam_ids(map_data, map_header, colorby, cat, 
-    primary_state, secondary_state):
+
+def get_sam_ids(map_data, map_header, colorby, cat,
+                primary_state, secondary_state):
     """ returns all sample ids matching the state strings and colorby:cat
-    
+
     colorby: eg: 'Country', or pass None to not filter only colorby:cat samples
     cat: e.g.: 'USA'
     primary_state: e.g.: 'AgeCategory:Child'
@@ -44,31 +46,30 @@ def get_sam_ids(map_data, map_header, colorby, cat,
 
     returns uniquified lists in randomized order
     """
-    if colorby == None:
+    if colorby is None:
         sample_ids = [sam[0] for sam in map_data]
     else:
 
-        sample_ids = get_sample_ids(\
-            map_data, map_header, {colorby:[cat]})
+        sample_ids = get_sample_ids(
+            map_data, map_header, {colorby: [cat]})
     # primary key is the category label, e.g. AgeCategory
     # value is the val for that category, e.g. Adult
 
     # go through age1/age2
     primary_states = parse_metadata_state_descriptions(primary_state)
-    if colorby != None:
+    if colorby is not None:
         primary_states[colorby] = [cat]
-    state1_samids = get_sample_ids(\
+    state1_samids = get_sample_ids(
         map_data, map_header, primary_states)
 
-    if secondary_state == None:
+    if secondary_state is None:
         state2_samids = set(sample_ids).difference(set(state1_samids))
     else:
         secondary_states =\
             parse_metadata_state_descriptions(secondary_state)
-        if colorby != None:
+        if colorby is not None:
             secondary_states[colorby] = [cat]
-        state2_samids = get_sample_ids(\
+        state2_samids = get_sample_ids(
             map_data, map_header, secondary_states)
-    
-    return list(set(state1_samids)), list(set(state2_samids))
 
+    return list(set(state1_samids)), list(set(state2_samids))
