@@ -4,15 +4,16 @@ __author__ = "Justin Kuczynski"
 __copyright__ = "Copyright 2011, The QIIME Project"
 __credits__ = ["Justin Kuczynski"]
 __license__ = "GPL"
-__version__ = "1.8.0"
+__version__ = "1.9.1"
 __maintainer__ = "Justin Kuczynski"
 __email__ = "justinak@gmail.com"
 """ computes cluster quality the default way, bet/within"""
 
+
 def clust_qual_ratio(dists, map_data, category):
     """ measures within category and between category dissimilarities
 
-    input: 
+    input:
     distance matrix [header, numpy 2d array],
     [map_dict, comments]
     category in mapping data (string)
@@ -24,17 +25,15 @@ def clust_qual_ratio(dists, map_data, category):
     if len(set(dist_headers)) != len(dist_headers):
         raise RuntimeError("Error: distance matrix headers are non unique")
 
-    cats = [map_dict[sam][category] for sam in map_dict]
-    cats.sort()
+    cats = sorted([map_dict[sam][category] for sam in map_dict])
     diff_dists = []
     same_dists = []
     for i in range(len(dist_headers)):
         for j in range(i):
             if map_dict[dist_headers[i]][category] == \
-             map_dict[dist_headers[j]][category]:
-                same_dists.append(dmtx[i,j])
+                    map_dict[dist_headers[j]][category]:
+                same_dists.append(dmtx[i, j])
             else:
-                diff_dists.append(dmtx[i,j])
+                diff_dists.append(dmtx[i, j])
 
-
-    return diff_dists, same_dists
\ No newline at end of file
+    return diff_dists, same_dists
