@@ -4,10 +4,10 @@ from __future__ import division
 """Functions supporting the QIIME denoiser"""
 
 __author__ = "Jens Reeder"
-__copyright__ = "Copyright 2011, The QIIME Project" 
+__copyright__ = "Copyright 2011, The QIIME Project"
 __credits__ = ["Jens Reeder", "Greg Caporaso"]
 __license__ = "GPL"
-__version__ = "1.8.0"
+__version__ = "1.9.1"
 __maintainer__ = "Justin Kuczynski"
 __email__ = "justinak@gmail.com"
 
@@ -15,19 +15,20 @@ from os import system, listdir, remove, rmdir
 from os.path import exists, split
 from re import search
 from itertools import chain
-from qiime.util import get_tmp_filename
-from cogent.parse.fasta import MinimalFastaParser
-from cogent.util.misc import remove_files, app_path
-from cogent.parse.flowgram_parser import lazy_parse_sff_handle
-from cogent.app.util import ApplicationNotFoundError, ApplicationError
-from cogent.parse.record import RecordError
+
+from skbio.parse.sequences import parse_fasta
+from bfillings.denoiser import lazy_parse_sff_handle
+from burrito.util import ApplicationNotFoundError, ApplicationError
+
 from qiime.util import load_qiime_config
 from qiime.denoiser.flowgram_clustering import denoise_seqs
 
-def fast_denoiser(sff_fps, fasta_fp, tmp_outdir, num_cpus, primer, verbose=True,
-                  titanium=False):
+
+def fast_denoiser(
+        sff_fps, fasta_fp, tmp_outdir, num_cpus, primer, verbose=True,
+        titanium=False):
     """wrapper function calling methods from the Denoiser package."""
-    if num_cpus>1:
+    if num_cpus > 1:
         denoise_seqs(sff_fps, fasta_fp, tmp_outdir,
                      primer=primer, cluster=True, num_cpus=num_cpus,
                      verbose=verbose, titanium=titanium)
@@ -35,16 +36,16 @@ def fast_denoiser(sff_fps, fasta_fp, tmp_outdir, num_cpus, primer, verbose=True,
         denoise_seqs(sff_fps, fasta_fp, tmp_outdir, primer=primer,
                      verbose=verbose, titanium=titanium)
 
-    #read centroids and singletons
-    centroids = MinimalFastaParser(open(tmp_outdir+"/centroids.fasta"))
-    singletons = MinimalFastaParser(open(tmp_outdir+"/singletons.fasta"))
-    
-    seqs = chain(centroids,singletons)
+    # read centroids and singletons
+    centroids = parse_fasta(open(tmp_outdir + "/centroids.fasta"))
+    singletons = parse_fasta(open(tmp_outdir + "/singletons.fasta"))
 
-    #read mapping 
+    seqs = chain(centroids, singletons)
+
+    # read mapping
     mapping = {}
-    cluster_mapping = open(tmp_outdir+"/denoiser_mapping.txt")
-    for i,cluster in enumerate(cluster_mapping):
+    cluster_mapping = open(tmp_outdir + "/denoiser_mapping.txt")
+    for i, cluster in enumerate(cluster_mapping):
         cluster, members = cluster.split(':')
         members = members.split()
         clust = [cluster]
@@ -52,7 +53,8 @@ def fast_denoiser(sff_fps, fasta_fp, tmp_outdir, num_cpus, primer, verbose=True,
         mapping[i] = clust
 
     return seqs, mapping
-    
+
+
 def extract_cluster_size(line):
     """ extract the size of a cluster from the header line.
 
