@@ -8,14 +8,20 @@ __credits__ = ["Jai Ram Rideout",
                "Greg Caporaso",
                "Jeremy Widmann"]
 __license__ = "GPL"
-__version__ = "1.8.0"
+__version__ = "1.9.1"
 __maintainer__ = "Jai Ram Rideout"
 __email__ = "jai.rideout@gmail.com"
 
 from collections import defaultdict
-from numpy import array
-from qiime.pycogent_backports.test import is_symmetric_and_hollow
-from qiime.parse import group_by_field
+from functools import partial
+
+import pandas as pd
+import numpy as np
+
+from qiime.stats import is_symmetric_and_hollow
+from qiime.parse import group_by_field, parse_mapping_file
+from qiime.filter import filter_mapping_file
+
 
 def get_grouped_distances(dist_matrix_header, dist_matrix, mapping_header,
                           mapping, field, within=True,
@@ -57,6 +63,7 @@ def get_grouped_distances(dist_matrix_header, dist_matrix, mapping_header,
     return _get_groupings(dist_matrix_header, dist_matrix, groups, within,
                           suppress_symmetry_and_hollowness_check)
 
+
 def get_all_grouped_distances(dist_matrix_header, dist_matrix, mapping_header,
                               mapping, field, within=True,
                               suppress_symmetry_and_hollowness_check=False):
@@ -95,6 +102,7 @@ def get_all_grouped_distances(dist_matrix_header, dist_matrix, mapping_header,
             results.append(distance)
     return results
 
+
 def get_field_state_comparisons(dist_matrix_header, dist_matrix,
                                 mapping_header, mapping, field,
                                 comparison_field_states,
@@ -134,6 +142,10 @@ def get_field_state_comparisons(dist_matrix_header, dist_matrix,
     _validate_input(dist_matrix_header, dist_matrix, mapping_header, mapping,
                     field)
 
+    # avoid empty groups of distances
+    mapping_header, mapping = filter_mapping_file(mapping, mapping_header,
+                                                  dist_matrix_header)
+
     # Make sure each comparison group field state is in the specified field.
     if not comparison_field_states:
         raise ValueError("You must provide at least one field state to "
@@ -155,9 +167,9 @@ def get_field_state_comparisons(dist_matrix_header, dist_matrix,
 
     # Get between distance groupings for the field of interest.
     between_groupings = get_grouped_distances(dist_matrix_header, dist_matrix,
-            mapping_header, mapping, field, within=False,
-            suppress_symmetry_and_hollowness_check=\
-                    suppress_symmetry_and_hollowness_check)
+                                              mapping_header, mapping, field, within=False,
+                                              suppress_symmetry_and_hollowness_check=
+                                              suppress_symmetry_and_hollowness_check)
 
     # Build up our 2D dictionary giving the distances between a field state and
     # a comparison group field state by filtering out the between_groupings
@@ -177,30 +189,31 @@ def get_field_state_comparisons(dist_matrix_header, dist_matrix,
                     result[field_state][comp_field_state] = group[2]
     return result
 
+
 def get_ordered_coordinates(coordinate_header,
                             coordinate_matrix,
                             order,
                             strict=False):
     """ Return coordinate vectors in order
-    
+
         coordinate_header: ids corresponding to vectors
-         in coordinate_matrix (element 0 of output of 
+         in coordinate_matrix (element 0 of output of
          qiime.parse.parse_coords)
         coordinate_matrix: the coordinate vectors (element 1 of
          output of qiime.parse.parse_coords)
-        order: ordered ids from coordinate_header (usually sample 
+        order: ordered ids from coordinate_header (usually sample
          ids) for coordinates that should be extracted
         strict: raise an error if an id from order is not present
          in coordinate_header (default: that id is ignored)
-        
-        The output of this function will be a tuple of the coordinate 
+
+        The output of this function will be a tuple of the coordinate
          vectors corresponding to each id in order, and the id order:
          (ordered_coordinates, ordered_ids)
         Note that the output order can be a subset of the input order
-         if some ids from order are not present in coordinate_header 
+         if some ids from order are not present in coordinate_header
          and strict == False.
-        
-        This function can be used in a way analogous to 
+
+        This function can be used in a way analogous to
          get_adjacent_distances to get a set of coordinates that
          might be connected by a line, for example.
     """
@@ -211,8 +224,9 @@ def get_ordered_coordinates(coordinate_header,
             coordinate_idx = coordinate_header.index(o)
         except ValueError:
             if strict:
-                raise ValueError,\
-                 "ID (%s) is not present in coordinate matrix" % o
+                raise ValueError(
+                    "ID (%s) is not present in coordinate matrix" %
+                    o)
             else:
                 pass
         else:
@@ -220,32 +234,33 @@ def get_ordered_coordinates(coordinate_header,
             ordered_ids.append(o)
     return ordered_coordinates, ordered_ids
 
+
 def get_adjacent_distances(dist_matrix_header,
                            dist_matrix,
                            sample_ids,
                            strict=False):
     """Return the distances between the adjacent sample_ids as a list
-    
+
     dist_matrix_header: distance matrix headers, e.g. the output
         of qiime.parse.parse_distmat (element 0)
-    dist_matrix: distance matrix, e.g., the output of 
+    dist_matrix: distance matrix, e.g., the output of
         qiime.parse.parse_distmat (element 1)
     sample_ids: a list of sample ids
-    strict: boolean indicating whether to raise ValueError if a 
-        sample_id is not in dm (default: False; sample_ids not in 
+    strict: boolean indicating whether to raise ValueError if a
+        sample_id is not in dm (default: False; sample_ids not in
         dm are ignored)
-       
+
     The output of this function will be a list of the distances
     between the adjacent sample_ids, and a list of the pair of sample ids
-    corresponding to each distance. This could subsequently be used, for 
-    example, to plot unifrac distances between days in a timeseries, as 
+    corresponding to each distance. This could subsequently be used, for
+    example, to plot unifrac distances between days in a timeseries, as
     d1 to d2, d2 to d3, d3 to d4, and so on. The list of pairs of sample
     ids are useful primarily in labeling axes when strict=False
-       
+
     WARNING: Only symmetric, hollow distance matrices may be used as input.
     Asymmetric distance matrices, such as those obtained by the UniFrac Gain
     metric (i.e. beta_diversity.py -m unifrac_g), should not be used as input.
-    
+
     """
     filtered_idx = []
     filtered_sids = []
@@ -254,28 +269,230 @@ def get_adjacent_distances(dist_matrix_header,
             idx = dist_matrix_header.index(sid)
         except ValueError:
             if strict:
-                raise ValueError,\
-                 "Sample ID (%s) is not present in distance matrix" % sid
+                raise ValueError(
+                    "Sample ID (%s) is not present in distance matrix" %
+                    sid)
             else:
                 pass
         else:
             filtered_idx.append(idx)
             filtered_sids.append(sid)
-    
+
     if len(filtered_idx) < 2:
-        raise ValueError, \
-         ("At least two of your sample_ids must be present in the"
-         " distance matrix. %d are present." % len(filtered_idx))
-    
+        raise ValueError("At least two of your sample_ids must be present in the"
+                         " distance matrix. %d are present." % len(filtered_idx))
+
     distance_results = []
     header_results = []
     for i in range(len(filtered_idx) - 1):
         distance_results.append(
-         dist_matrix[filtered_idx[i]][filtered_idx[i+1]])
+            dist_matrix[filtered_idx[i]][filtered_idx[i + 1]])
         header_results.append(
-         (filtered_sids[i], filtered_sids[i+1]))
+            (filtered_sids[i], filtered_sids[i + 1]))
     return distance_results, header_results
 
+def _group_by_sample_metadata(collapsed_md, sample_id_field="SampleID"):
+    """Group sample identifiers by one or more metadata fields
+
+    Parameters
+    ----------
+    collapsed_md : pd.DataFrame
+        The result of collapsing a sample metadata DataFrame, for example with
+        collapse_metadata.
+    sample_id_field : str, optional
+        The sample id field in the mapping_f.
+
+    Returns
+    -------
+    dict
+        Mapping of group id to set of input sample ids in that group.
+    dict
+        Mapping of input sample id to new group id.
+    pd.DataFrame
+        Sample metadata resulting from the collapse operation.
+
+    Raises
+    ------
+    KeyError
+        If sample_id_field or any of the collapse fields are not column headers
+        in mapping_f.
+
+    """
+    new_index_to_group = {}
+    old_index_to_new_index = {}
+    for i in collapsed_md.index:
+        old_indices = collapsed_md[sample_id_field][i]
+
+        # this is a little ugly, but we need to handle single and multi-index
+        # values here, and we always want to result to be a tuple
+        if isinstance(i, tuple):
+            new_index = i
+        else:
+            new_index = (i, )
+
+        new_index_to_group[new_index] = set(old_indices)
+        for old_index in old_indices:
+            old_index_to_new_index[old_index] = new_index
+
+    return new_index_to_group, old_index_to_new_index
+
+def get_collapse_fns():
+    """ Return lookup of functions that can be used with biom.Table.collapse
+    """
+    return {'median': _collapse_to_median,
+            'first': _collapse_to_first,
+            'random': _collapse_to_random,
+            'sum': _collapse_to_sum,
+            'mean': _collapse_to_mean}
+
+def collapse_samples(table, mapping_f, collapse_fields, collapse_mode):
+    """ Collapse samples in a biom table and sample metadata
+
+    Parameters
+    ----------
+    table : biom.Table
+        The biom table to be collapsed.
+    mapping_f : file handle or filepath
+        The sample metadata mapping file.
+    collapse_fields : iterable
+        The fields to combine when collapsing samples. For each sample in the
+        mapping_f, the ordered values from these columns will be tuplized and
+        used as the group identfier. Samples whose tuplized values in these
+        fields are identical will be grouped.
+    collapse_mode : str {sum, mean, median, random, first}
+        The strategy to use for collapsing counts in the table.
+
+    Returns
+    -------
+    biom.Table
+        The collapsed biom table.
+    pd.DataFrame
+        Sample metadata resulting from the collapse operation.
+
+    Raises
+    ------
+    KeyError
+        If sample_id_field or any of the collapse fields are not column headers
+        in mapping_f.
+
+    """
+    collapsed_metadata = _collapse_metadata(mapping_f,
+                                            collapse_fields)
+
+    new_index_to_group, old_index_to_new_index = \
+        _group_by_sample_metadata(collapsed_metadata)
+    partition_f = partial(_sample_id_from_group_id,
+                          sid_to_group_id=old_index_to_new_index)
+
+    collapse_fns = get_collapse_fns()
+    try:
+        collapse_f = collapse_fns[collapse_mode]
+    except KeyError:
+        raise KeyError(
+         "Unknown collapse function %s. Valid choices are: "
+         "%s." % (collapse_mode, ', '.join(collapse_fns.keys())))
+    output_table = table.collapse(
+        partition_f, collapse_f=collapse_f, norm=False, axis='sample')
+
+    return collapsed_metadata, output_table
+
+def mapping_lines_from_collapsed_df(collapsed_df):
+    """ Formats a multi-index DataFrame as lines of a QIIME mapping file
+
+    Parameters
+    ----------
+    collapsed_df : pd.DataFrame
+        Sample metadata resulting from the collapse operation.
+
+    Returns
+    -------
+    list of strings
+        Lines representing the text of a QIIME mapping file.
+    """
+    lines = []
+    lines.append('\t'.join(['#SampleID', 'original-sample-ids'] +\
+                           list(collapsed_df.columns)[1:]))
+
+    for r in collapsed_df.iterrows():
+        # this is a little ugly, but we need to handle single and multi-index
+        # values here
+        if isinstance(r[0], tuple):
+            new_idx = '.'.join(map(str, r[0]))
+        else:
+            new_idx = str(r[0])
+        new_values = []
+        for e in r[1]:
+            if len(set(e)) == 1:
+                # if all samples in the replicate group have the same
+                # value for this column, just store that value
+                new_values.append(str(e[0]))
+            else:
+                # if any samples in the replicate group differ in the value
+                # in this column, store all of the values in the same order
+                # as the ids in the new "original-sample-ids" column
+                new_values.append('(%s)' % ', '.join(map(str,e)))
+        lines.append('\t'.join([new_idx] + new_values))
+    return lines
+
+def _collapse_metadata(mapping_f, collapse_fields):
+    """ Load a mapping file into a DataFrame and then collapse rows
+
+    Parameters
+    ----------
+    mapping_f : file handle or filepath
+        The sample metadata mapping file.
+    collapse_fields : iterable
+        The fields to combine when collapsing samples. For each sample in the
+        mapping_f, the ordered values from these columns will be tuplized and
+        used as the group identfier. Samples whose tuplized values in these
+        fields are identical will be grouped.
+
+    Returns
+    -------
+    pd.DataFrame
+        Sample metadata resulting from the collapse operation.
+
+    Raises
+    ------
+    KeyError
+        If sample_id_field or any of the collapse fields are not column headers
+        in mapping_f.
+
+    """
+    mapping_data, header, _ = parse_mapping_file(mapping_f)
+    sample_md = pd.DataFrame(mapping_data, columns=header)
+    grouped = sample_md.groupby(collapse_fields)
+    collapsed_md = grouped.agg(lambda x: tuple(x))
+    return collapsed_md
+
+def _sample_id_from_group_id(id_, md, sid_to_group_id):
+    try:
+        group_id = sid_to_group_id[id_]
+    except KeyError:
+        raise KeyError("Sample id %s doesn't map to a group id." % id_)
+    return '.'.join(map(str, group_id))
+
+def _collapse_to_first(t, axis):
+    return np.asarray([e[0] for e in t.iter_data(axis=axis, dense=True)])
+
+def _collapse_to_median(t, axis):
+    return np.asarray([np.median(e) for e in t.iter_data(axis=axis, dense=True)])
+
+def _collapse_to_sum(t, axis):
+    return np.asarray([np.sum(e) for e in t.iter_data(axis=axis)])
+
+def _collapse_to_mean(t, axis):
+    return np.asarray([np.mean(e) for e in t.iter_data(axis=axis)])
+
+def _collapse_to_random(t, axis):
+    if axis == 'sample':
+        length = t.length("observation")
+    elif axis == 'observation':
+        length = t.length("sample")
+    else:
+        raise UnknownAxisError(axis)
+    n = np.random.randint(length)
+    return np.asarray([e[n] for e in t.iter_data(axis=axis, dense=True)])
 
 def _validate_input(dist_matrix_header, dist_matrix, mapping_header, mapping,
                     field):
@@ -285,7 +502,7 @@ def _validate_input(dist_matrix_header, dist_matrix, mapping_header, mapping,
     data should not be None. The field must exist in the mapping header.
     """
     if (dist_matrix_header is None or dist_matrix is None or mapping_header is
-        None or mapping is None or field is None):
+            None or mapping is None or field is None):
         raise ValueError("The input(s) cannot be 'None'.")
 
     # Make sure the appropriate input is iterable.
@@ -306,6 +523,12 @@ def _validate_input(dist_matrix_header, dist_matrix, mapping_header, mapping,
         raise ValueError("The field '%s' is not in the mapping file header."
                          % field)
 
+    # check that we share sample identifiers between th mf and the dm
+    if not set(zip(*mapping)[0]) & set(dist_matrix_header):
+        raise ValueError('The mapping file does not share at least one sample'
+                         ' with the distance matrix.')
+
+
 def _get_indices(input_items, wanted_items):
     """Returns indices of the wanted items in the input items if present.
 
@@ -315,7 +538,7 @@ def _get_indices(input_items, wanted_items):
     as a scalar, not an iterable.
     """
     # Note: Some of this code is taken from Jeremy Widmann's
-    # get_valid_indices() function, part of make_distance_histograms.py.
+    # get_valid_indices() function, part of make_distance_histograms.py from QIIME 1.8.0.
     try:
         iter(input_items)
     except:
@@ -331,6 +554,7 @@ def _get_indices(input_items, wanted_items):
     return [input_items.index(item)
             for item in wanted_items if item in input_items]
 
+
 def _get_groupings(dist_matrix_header, dist_matrix, groups, within=True,
                    suppress_symmetry_and_hollowness_check=False):
     """Returns a list of distance groupings.
@@ -356,12 +580,12 @@ def _get_groupings(dist_matrix_header, dist_matrix, groups, within=True,
           is fairly fast. However, if you *know* you have a symmetric and
           hollow distance matrix, you can disable this check for small
           performance gains on extremely large distance matrices
-    
+
     If within is True, the zeros along the diagonal of the distance matrix are
     omitted.
     """
     # Note: Much of this code is taken from Jeremy Widmann's
-    # distances_by_groups() function, part of make_distance_histograms.py.
+    # distances_by_groups() function, part of make_distance_histograms.py from QIIME 1.8.0.
     if not suppress_symmetry_and_hollowness_check:
         if not is_symmetric_and_hollow(dist_matrix):
             raise ValueError("The distance matrix must be symmetric and "
@@ -374,22 +598,22 @@ def _get_groupings(dist_matrix_header, dist_matrix, groups, within=True,
         if within:
             # Handle the case where indices are the same so we need to omit
             # the diagonal.
-            block = dist_matrix[row_indices][:,row_indices]
+            block = dist_matrix[row_indices][:, row_indices]
 
             size = len(row_indices)
             indices = []
             for i in range(size):
-                for j in range(i,size):
+                for j in range(i, size):
                     if i != j:
                         indices.append(block[i][j])
             if indices:
                 result.append((row_group, row_group, indices))
         else:
             # Handle the case where indices are separate: just return blocks.
-            for j in range(i+1, len(groups)):
+            for j in range(i + 1, len(groups)):
                 col_group, col_ids = group_items[j]
                 col_indices = _get_indices(dist_matrix_header, col_ids)
-                vals = dist_matrix[row_indices][:,col_indices]
+                vals = dist_matrix[row_indices][:, col_indices]
 
                 # Flatten the array into a single-level list.
                 vals = map(None, vals.flat)
@@ -399,13 +623,13 @@ def _get_groupings(dist_matrix_header, dist_matrix, groups, within=True,
 
 
 def extract_per_individual_states_from_sample_metadata(
-      sample_metadata,
-      state_category,
-      state_values,
-      individual_identifier_category,
-      filter_missing_data=True):
+        sample_metadata,
+        state_category,
+        state_values,
+        individual_identifier_category,
+        filter_missing_data=True):
     """
-    sample_metadata : 2d dictionary mapping sample ids to metadata (as 
+    sample_metadata : 2d dictionary mapping sample ids to metadata (as
      returned from qiime.parse.parse_mapping_file_to_dict)
     state_category: metadata category name describing state of interest
      (usually something like 'TreatmentState') as a string
@@ -413,11 +637,11 @@ def extract_per_individual_states_from_sample_metadata(
      metadata entry (usually something like ['PreTreatment','PostTreatment'])
     individual_identifier_category: metadata category name describing the
      individual (usually something like 'PersonalID') as a string
-    filter_missing_data: if True, an individual is excluded 
+    filter_missing_data: if True, an individual is excluded
      from the result object if any of it's values are None. This can occur
      when there is no sample for one or more of the state values for an
      individual. This is True by default.
-    
+
     returns {'individual-identifier':
                [sample-id-at-state-value1,
                 sample-id-at-state-value2,
@@ -428,33 +652,32 @@ def extract_per_individual_states_from_sample_metadata(
     """
     # prep the result object, which will be a dict of lists
     len_state_values = len(state_values)
+
     def inner_dict_constructor():
         return [None] * len_state_values
     results = defaultdict(inner_dict_constructor)
-    
+
     for sample_id, metadata in sample_metadata.items():
         try:
             individual_id = metadata[individual_identifier_category]
         except KeyError:
-            raise KeyError, \
-             "%s is not a sample metadata category." %\
-             individual_identifier_category
+            raise KeyError("%s is not a sample metadata category." %
+                           individual_identifier_category)
         try:
             state_value = metadata[state_category]
         except KeyError:
-            raise KeyError, \
-             "%s is not a sample metadata category." %\
-             state_category
-             
+            raise KeyError("%s is not a sample metadata category." %
+                           state_category)
+
         try:
             state_index = state_values.index(state_value)
         except ValueError:
-            # hit a state that is in the mapping file but not in 
+            # hit a state that is in the mapping file but not in
             # state_values - this is silently ignored
             continue
-        
+
         results[individual_id][state_index] = sample_id
-        
+
     if filter_missing_data:
         # delete individual results if sample ids corresponding to
         # any of the states are missing
@@ -463,6 +686,7 @@ def extract_per_individual_states_from_sample_metadata(
                 del results[individual_id]
     return results
 
+
 def extract_per_individual_state_metadatum_from_sample_metadata(
         sample_metadata,
         state_category,
@@ -471,7 +695,7 @@ def extract_per_individual_state_metadatum_from_sample_metadata(
         metadata_category,
         process_f=float):
     """
-    sample_metadata : 2d dictionary mapping sample ids to metadata (as 
+    sample_metadata : 2d dictionary mapping sample ids to metadata (as
      returned from qiime.parse.parse_mapping_file_to_dict)
     state_category: metadata category name describing state of interest
      (usually something like 'TreatmentState') as a string
@@ -481,7 +705,7 @@ def extract_per_individual_state_metadatum_from_sample_metadata(
      individual (usually something like 'PersonalID') as a string
     metadata_category: metadata category to extract from sample_metadata
     process_f: function to apply to metadata values (default: float)
-    
+
     returns {'individual-identifier':
                [state-1-metadata-value,
                 state-2-metadata-value,
@@ -490,29 +714,33 @@ def extract_per_individual_state_metadatum_from_sample_metadata(
              }
     """
     per_individual_states = extract_per_individual_states_from_sample_metadata(
-     sample_metadata,
-     state_category,
-     state_values,
-     individual_identifier_category,
-     filter_missing_data=True)
-    
+        sample_metadata,
+        state_category,
+        state_values,
+        individual_identifier_category,
+        filter_missing_data=True)
+
     results = {}
     for individual_id, sample_ids in per_individual_states.items():
         per_state_metadata_values = []
         for sample_id in sample_ids:
             try:
-                sample_metadata_value = sample_metadata[sample_id][metadata_category]
+                sample_metadata_value = sample_metadata[
+                    sample_id][
+                    metadata_category]
             except KeyError:
-                raise KeyError, \
-                 "%s is not a sample metadata category." % metadata_category
+                raise KeyError(
+                    "%s is not a sample metadata category." %
+                    metadata_category)
             try:
                 v = process_f(sample_metadata_value)
-            except ValueError, e:
+            except ValueError as e:
                 v = None
             per_state_metadata_values.append(v)
         results[individual_id] = per_state_metadata_values
     return results
 
+
 def extract_per_individual_state_metadata_from_sample_metadata(
         sample_metadata,
         state_category,
@@ -521,7 +749,7 @@ def extract_per_individual_state_metadata_from_sample_metadata(
         metadata_categories,
         process_f=float):
     """
-    sample_metadata : 2d dictionary mapping sample ids to metadata (as 
+    sample_metadata : 2d dictionary mapping sample ids to metadata (as
      returned from qiime.parse.parse_mapping_file_to_dict)
     state_category: metadata category name describing state of interest
      (usually something like 'TreatmentState') as a string
@@ -531,7 +759,7 @@ def extract_per_individual_state_metadata_from_sample_metadata(
      individual (usually something like 'PersonalID') as a string
     metadata_categories: metadata categories to extract from sample_metadata
     process_f: function to apply to metadata values (default: float)
-    
+
     returns {'metadata-category-1':
               {'individual-identifier-1':
                [difference-in-metadata-value-bw-states-2-and-1,
@@ -548,15 +776,16 @@ def extract_per_individual_state_metadata_from_sample_metadata(
     results = {}
     for metadata_category in metadata_categories:
         results[metadata_category] = \
-         extract_per_individual_state_metadatum_from_sample_metadata(
-           sample_metadata,
-           state_category,
-           state_values,
-           individual_identifier_category,
-           metadata_category,
-           process_f)
+            extract_per_individual_state_metadatum_from_sample_metadata(
+                sample_metadata,
+                state_category,
+                state_values,
+                individual_identifier_category,
+                metadata_category,
+                process_f)
     return results
 
+
 def extract_per_individual_state_metadata_from_sample_metadata_and_biom(
         sample_metadata,
         biom_table,
@@ -565,9 +794,9 @@ def extract_per_individual_state_metadata_from_sample_metadata_and_biom(
         individual_identifier_category,
         observation_ids=None):
     """
-    sample_metadata : 2d dictionary mapping sample ids to metadata (as 
+    sample_metadata : 2d dictionary mapping sample ids to metadata (as
      returned from qiime.parse.parse_mapping_file_to_dict)
-    biom_table: biom table object containing observation counts for 
+    biom_table: biom table object containing observation counts for
      samples in sample_metadata
     state_category: metadata category name describing state of interest
      (usually something like 'TreatmentState') as a string
@@ -577,7 +806,7 @@ def extract_per_individual_state_metadata_from_sample_metadata_and_biom(
      individual (usually something like 'PersonalID') as a string
     observation_ids: observations (usually OTUs) to extract from biom_table
      (default is all)
-    
+
     returns {'otu1':
               {'individual-identifier-1:
                [difference-in-otu1-abundance-bw-states-2-and-1,
@@ -592,21 +821,22 @@ def extract_per_individual_state_metadata_from_sample_metadata_and_biom(
               }
     """
     per_individual_states = extract_per_individual_states_from_sample_metadata(
-     sample_metadata,
-     state_category,
-     state_values,
-     individual_identifier_category,
-     filter_missing_data=True)
+        sample_metadata,
+        state_category,
+        state_values,
+        individual_identifier_category,
+        filter_missing_data=True)
     results = {}
     if observation_ids is None:
-        observation_ids = biom_table.ObservationIds
+        observation_ids = biom_table.ids(axis='observation')
     for observation_id in observation_ids:
-        observation_data = biom_table.observationData(observation_id)
+        observation_data = biom_table.data(observation_id, 'observation')
         results[observation_id] = {}
         for individual_id, sample_ids in per_individual_states.items():
             per_state_metadata_values = []
             for sample_id in sample_ids:
-                sample_index = biom_table.getSampleIndex(sample_id)
-                per_state_metadata_values.append(observation_data[sample_index])
+                sample_index = biom_table.index(sample_id, 'sample')
+                per_state_metadata_values.append(
+                    observation_data[sample_index])
             results[observation_id][individual_id] = per_state_metadata_values
     return results
