@@ -4,7 +4,7 @@ __author__ = "Justin Kuczynski"
 __copyright__ = "Copyright 2011, The QIIME Project"
 __credits__ = ["Justin Kuczynski"]
 __license__ = "GPL"
-__version__ = "1.8.0"
+__version__ = "1.9.1"
 __maintainer__ = "Justin Kuczynski"
 __email__ = "justinak@gmail.com"
 
@@ -15,11 +15,13 @@ import warnings
 warnings.filterwarnings('ignore', 'Not using MPI as mpi4py not found')
 from optparse import OptionParser
 from qiime.parse import parse_distmat
-from cogent.core.tree import PhyloNode
-from cogent.cluster.UPGMA import UPGMA_cluster
-from cogent.phylo.nj import nj
+from scipy.cluster.hierarchy import linkage
+from skbio.tree import TreeNode
+from skbio.stats.distance import DistanceMatrix
+from skbio.tree import nj
 import os.path
 
+
 def multiple_file_upgma(input_dir, output_dir):
     if not os.path.exists(output_dir):
         os.makedirs(output_dir)
@@ -29,52 +31,43 @@ def multiple_file_upgma(input_dir, output_dir):
     for fname in file_names:
         base_fname, ext = os.path.splitext(fname)
         single_file_upgma(os.path.join(input_dir, fname),
-            os.path.join(output_dir,'upgma_'+base_fname+'.tre'))
+                          os.path.join(output_dir, 'upgma_' + base_fname + '.tre'))
+
 
 def single_file_upgma(input_file, output_file):
     # read in dist matrix
-    f = open(input_file, 'U')
-    headers, data = parse_distmat(f)
-    f.close()
-    
-    # do upgma
-    nodes = map(PhyloNode, headers)
-    BIG = 1e305
-    U = data.copy()
-    for i in range(len(U)):
-        U[i,i] = BIG
-    c = UPGMA_cluster(U, nodes, BIG)
+    dist_mat = DistanceMatrix.read(input_file)
+
+    # SciPy uses average as UPGMA:
+    # http://docs.scipy.org/doc/scipy/reference/generated/
+    #    scipy.cluster.hierarchy.linkage.html#scipy.cluster.hierarchy.linkage
+    linkage_matrix = linkage(dist_mat.condensed_form(), method='average')
+
+    tree = TreeNode.from_linkage_matrix(linkage_matrix, dist_mat.ids)
 
     # write output
-    f = open(output_file,'w')
+    f = open(output_file, 'w')
     try:
-        f.write(c.getNewick(with_distances=True))
+        f.write(tree.to_newick(with_distances=True))
     except AttributeError:
-        if c == None:
+        if c is None:
             raise RuntimeError("""input file %s did not make a UPGMA tree.
  Ensure it has more than one sample present""" % (str(input_file),))
         raise
     f.close()
 
+
 def single_file_nj(input_file, output_file):
-    # read in dist matrix
-    f = open(input_file, 'U')
-    headers, data = parse_distmat(f)
-    f.close()
+    dm = DistanceMatrix.read(input_file)
 
-    # do nj
-    distdict = {}
-    for i in range(len(headers)):
-        for j in range(len(headers)):
-            distdict[(headers[i],headers[j])] = data[i,j] # need j,i too?
-
-    tree = nj(distdict)
+    tree = nj(dm)
 
     # write output
-    f = open(output_file,'w')
-    f.write(tree.getNewick(with_distances=True))
+    f = open(output_file, 'w')
+    f.write(tree.to_newick(with_distances=True))
     f.close()
 
+
 def multiple_file_nj(input_dir, output_dir):
     if not os.path.exists(output_dir):
         os.makedirs(output_dir)
@@ -84,4 +77,4 @@ def multiple_file_nj(input_dir, output_dir):
     for fname in file_names:
         base_fname, ext = os.path.splitext(fname)
         single_file_nj(os.path.join(input_dir, fname),
-            os.path.join(output_dir,'nj_'+base_fname+'.tre'))
\ No newline at end of file
+                       os.path.join(output_dir, 'nj_' + base_fname + '.tre'))
