@@ -5,22 +5,26 @@ __author__ = "Jai Ram Rideout"
 __copyright__ = "Copyright 2012, The QIIME project"
 __credits__ = ["Jai Ram Rideout"]
 __license__ = "GPL"
-__version__ = "1.8.0"
+__version__ = "1.9.1"
 __maintainer__ = "Jai Ram Rideout"
 __email__ = "jai.rideout@gmail.com"
 
 """Contains functions used in the make_distance_boxplots.py script."""
 
 from collections import defaultdict
-from numpy import argsort, array, median
+
+import numpy as np
+
 from qiime.colors import data_colors, data_color_order
 from qiime.format import format_mapping_file
 from qiime.group import get_all_grouped_distances, get_grouped_distances
-from qiime.make_distance_histograms import matplotlib_rgb_color
+from qiime.colors import matplotlib_rgb_color
 from qiime.parse import parse_distmat, parse_mapping_file
-from qiime.pycogent_backports.distribution_plots import generate_box_plots
+from skbio.draw import boxplots
 from qiime.util import MetadataMap
 
+SORT_TYPES = ('median', 'alphabetical')
+
 def make_distance_boxplots(dm_f,
                            map_f,
                            fields,
@@ -36,7 +40,7 @@ def make_distance_boxplots(dm_f,
                            box_width=0.5,
                            box_color=None,
                            color_individual_within_by_field=None,
-                           sort=False):
+                           sort=None):
     """Generates various types of boxplots for distance comparisons.
 
     Returns a list of tuples, one for each field. Each tuple contains the
@@ -118,9 +122,9 @@ def make_distance_boxplots(dm_f,
             # list of colors and a legend.
             if color_individual_within_by_field is not None:
                 colors, color_mapping = _color_field_states(
-                        format_mapping_file(map_header, map_data).split('\n'),
-                        dm_header, field, field_states,
-                        color_individual_within_by_field)
+                    format_mapping_file(map_header, map_data).split('\n'),
+                    dm_header, field, field_states,
+                    color_individual_within_by_field)
                 plot_colors.extend(colors)
                 legend = (color_mapping.values(), color_mapping.keys())
             else:
@@ -128,7 +132,7 @@ def make_distance_boxplots(dm_f,
 
         if not suppress_individual_between:
             between_dists = get_grouped_distances(dm_header, dm_data,
-                    map_header, map_data, field, within=False)
+                                                  map_header, map_data, field, within=False)
 
             for grouping in between_dists:
                 plot_data.append(grouping[2])
@@ -141,15 +145,14 @@ def make_distance_boxplots(dm_f,
 
         assert (len(plot_data) == len(plot_labels) and
                 len(plot_labels) == len(plot_colors)), "The number " +\
-                "of boxplot labels and colors do not match the number of " +\
-                "boxplots."
+            "of boxplot labels and colors do not match the number of " +\
+            "boxplots."
 
         # We now have our data and labels ready, so plot them!
         if plot_data:
-            if sort:
-                plot_data, plot_labels, plot_colors = \
-                        _sort_distributions_by_median(plot_data, plot_labels,
-                                                      plot_colors)
+            if sort is not None:
+                plot_data, plot_labels, plot_colors = _sort_distributions(
+                    plot_data, plot_labels, plot_colors, sort)
 
             if width is None:
                 width = len(plot_data) * box_width + 2
@@ -157,13 +160,15 @@ def make_distance_boxplots(dm_f,
                 raise ValueError("The specified width and height of the plot "
                                  "must be greater than zero.")
 
-            plot_figure = generate_box_plots(plot_data,
-                    x_tick_labels=plot_labels, title="%s Distances" % field,
-                    x_label="Grouping", y_label="Distance",
-                    x_tick_labels_orientation='vertical', y_min=y_min,
-                    y_max=y_max, whisker_length=whisker_length,
-                    box_width=box_width, box_colors=plot_colors,
-                    figure_width=width, figure_height=height, legend=legend)
+            plot_figure = boxplots(plot_data, x_tick_labels=plot_labels,
+                                   title="%s Distances" % field,
+                                   x_label="Grouping", y_label="Distance",
+                                   x_tick_labels_orientation='vertical',
+                                   y_min=y_min, y_max=y_max,
+                                   whisker_length=whisker_length,
+                                   box_width=box_width, box_colors=plot_colors,
+                                   figure_width=width, figure_height=height,
+                                   legend=legend)
 
             results.append((field, plot_figure, plot_data, plot_labels,
                             plot_colors))
@@ -173,6 +178,7 @@ def make_distance_boxplots(dm_f,
 
     return results
 
+
 def _cast_y_axis_extrema(y_axis_extrema):
     """Casts to float; handles 'auto' value as well."""
     try:
@@ -186,24 +192,23 @@ def _cast_y_axis_extrema(y_axis_extrema):
                              y_axis_extrema)
     return y_axis_extrema
 
-def _sort_distributions_by_median(plot_data, plot_labels, plot_colors):
-    """Sorts plot data, labels, and colors in order of increasing median."""
-    sorted_data = []
 
-    for distribution, label, color in zip(plot_data, plot_labels, plot_colors):
-        sorted_data.append((median(distribution), distribution, label, color))
-    sorted_data.sort()
+def _sort_distributions(plot_data, plot_labels, plot_colors, sort_type):
+    """Sort plot data, labels, and colors.
 
-    plot_data = []
-    plot_labels = []
-    plot_colors = []
+    Can sort in order of increasing median or alphabetically (based on plot
+    labels).
 
-    for _, distribution, label, color in sorted_data:
-        plot_data.append(distribution)
-        plot_labels.append(label)
-        plot_colors.append(color)
+    """
+    if sort_type == 'median':
+        sort_key = lambda item: np.median(item[0])
+    elif sort_type == 'alphabetical':
+        sort_key = lambda item: item[1]
+    else:
+        raise ValueError("Invalid sort type '%s'." % sort_type)
 
-    return plot_data, plot_labels, plot_colors
+    # Taken from http://stackoverflow.com/a/9764364
+    return zip(*sorted(zip(plot_data, plot_labels, plot_colors), key=sort_key))
 
 def _color_field_states(map_f, samp_ids, field, field_states, color_by_field):
     """Colors one field by another.
