@@ -6,28 +6,30 @@ __author__ = "Greg Caporaso"
 __copyright__ = "Copyright 2011, The QIIME project"
 __credits__ = ["Greg Caporaso"]
 __license__ = "GPL"
-__version__ = "1.8.0"
+__version__ = "1.9.1"
 __maintainer__ = "Greg Caporaso"
 __email__ = "gregcaporaso@gmail.com"
 
 from os.path import join, split, splitext
-from cogent.util.misc import create_dir
-from biom.parse import parse_biom_table
+from skbio.util import create_dir
+from biom import load_table
+
 from qiime.parallel.util import ParallelWrapper
 from qiime.format import format_distance_matrix
 
+
 class ParallelBetaDiversity(ParallelWrapper):
     _script_name = "beta_diversity.py"
     _input_splitter = ParallelWrapper._input_existing_filepaths
     _job_prefix = 'BDIV'
 
-    def _identify_files_to_remove(self,job_result_filepaths,params):
+    def _identify_files_to_remove(self, job_result_filepaths, params):
         """ The output of the individual jobs are the files we want to keep
         """
         return []
-    
-    def _commands_to_shell_script(self,commands,fp,shebang='#!/bin/bash'):
-        f = open(fp,'w')
+
+    def _commands_to_shell_script(self, commands, fp, shebang='#!/bin/bash'):
+        f = open(fp, 'w')
         f.write(shebang)
         f.write('\n')
         f.write('\n'.join(commands))
@@ -37,7 +39,7 @@ class ParallelBetaDiversity(ParallelWrapper):
 
 class ParallelBetaDiversitySingle(ParallelBetaDiversity):
 
-    def _identify_files_to_remove(self,job_result_filepaths,params):
+    def _identify_files_to_remove(self, job_result_filepaths, params):
         """ The output of the individual jobs are the files we want to keep
         """
         return job_result_filepaths
@@ -49,13 +51,19 @@ class ParallelBetaDiversitySingle(ParallelBetaDiversity):
                               output_dir,
                               merge_map_filepath):
 
-        merge_map_f = open(merge_map_filepath,'w')
-    
+        merge_map_f = open(merge_map_filepath, 'w')
+
         for metric in params['metrics'].split(','):
-            fps_to_merge = [fp for fp in job_result_filepaths if '/%s_' % metric in fp]
-            output_fp = join(output_dir,'%s_%s.txt' % (metric,input_file_basename))
-            merge_map_f.write('%s\t%s\n' % ('\t'.join(fps_to_merge),output_fp))
-    
+            fps_to_merge = [
+                fp for fp in job_result_filepaths if '/%s_' %
+                metric in fp]
+            output_fp = join(
+                output_dir, '%s_%s.txt' %
+                (metric, input_file_basename))
+            merge_map_f.write(
+                '%s\t%s\n' %
+                ('\t'.join(fps_to_merge), output_fp))
+
         merge_map_f.close()
 
     def _get_job_commands(self,
@@ -67,27 +75,27 @@ class ParallelBetaDiversitySingle(ParallelBetaDiversity):
                           command_prefix='/bin/bash; ',
                           command_suffix='; exit'):
         """Generate beta diversity to split single OTU table to multiple jobs
-    
+
         full_tree=True is faster: beta_diversity.py -f will make things
         go faster, but be sure you already have the correct minimal tree.
         """
         commands = []
         result_filepaths = []
-    
-        sids = parse_biom_table(open(input_fp,'U')).SampleIds
-        
+
+        sids = load_table(input_fp).ids()
+
         if params['full_tree']:
             full_tree_str = '-f'
         else:
             full_tree_str = ''
-        
+
         if params['tree_path']:
             tree_str = '-t %s' % params['tree_path']
         else:
             tree_str = ''
-        
+
         metrics = params['metrics']
-        
+
         # this is a little bit of an abuse of _merge_to_n_commands, so may
         # be worth generalizing that method - this determines the correct
         # number of samples to process in each command
@@ -96,7 +104,7 @@ class ParallelBetaDiversitySingle(ParallelBetaDiversity):
                                                      delimiter=',',
                                                      command_prefix='',
                                                      command_suffix='')
-                                                     
+
         for i, sample_id_group in enumerate(sample_id_groups):
             working_dir_i = join(working_dir, str(i))
             create_dir(working_dir_i)
@@ -105,24 +113,24 @@ class ParallelBetaDiversitySingle(ParallelBetaDiversity):
             result_filepaths.append(output_dir_i)
             input_dir, input_fn = split(input_fp)
             input_basename, input_ext = splitext(input_fn)
-            sample_id_desc = sample_id_group.replace(',','_')
-            output_fns = ['%s_%s.txt' % (metric, input_basename) \
-             for metric in metrics.split(',')]
-            rename_command, current_result_filepaths = self._get_rename_command(\
-             output_fns,working_dir_i,output_dir_i)
+            sample_id_desc = sample_id_group.replace(',', '_')
+            output_fns = ['%s_%s.txt' % (metric, input_basename)
+                          for metric in metrics.split(',')]
+            rename_command, current_result_filepaths = self._get_rename_command(
+                output_fns, working_dir_i, output_dir_i)
 
             result_filepaths += current_result_filepaths
 
             bdiv_command = '%s -i %s -o %s %s -m %s %s -r %s' %\
-             (self._script_name,\
-              input_fp,
-              working_dir_i,
-              tree_str,
-              params['metrics'],
-              full_tree_str,
-              sample_id_group)
+                (self._script_name,
+                 input_fp,
+                 working_dir_i,
+                 tree_str,
+                 params['metrics'],
+                 full_tree_str,
+                 sample_id_group)
 
-            shell_script_fp = '%s/%s%d.sh' % (working_dir_i,job_prefix,i)
+            shell_script_fp = '%s/%s%d.sh' % (working_dir_i, job_prefix, i)
             shell_script_commands = [bdiv_command] + rename_command.split(';')
             self._commands_to_shell_script(shell_script_commands,
                                            shell_script_fp)
@@ -132,9 +140,8 @@ class ParallelBetaDiversitySingle(ParallelBetaDiversity):
                                              params['jobs_to_start'],
                                              command_prefix=command_prefix,
                                              command_suffix=command_suffix)
-        
-        return commands, result_filepaths
 
+        return commands, result_filepaths
 
     def _get_poller_command(self,
                             expected_files_filepath,
@@ -145,16 +152,17 @@ class ParallelBetaDiversitySingle(ParallelBetaDiversity):
         """Generate command to initiate a poller to monitior/process completed runs
         """
         result = '%s poller.py -f %s -m %s -d %s -t %d -p %s %s' % \
-         (command_prefix,
-          expected_files_filepath,
-          merge_map_filepath,
-          deletion_list_filepath,
-          self._seconds_to_sleep,
-          'qiime.parallel.beta_diversity.parallel_beta_diversity_process_run_results_f',
-          command_suffix)
-      
+            (command_prefix,
+             expected_files_filepath,
+             merge_map_filepath,
+             deletion_list_filepath,
+             self._seconds_to_sleep,
+             'qiime.parallel.beta_diversity.parallel_beta_diversity_process_run_results_f',
+             command_suffix)
+
         return result, []
 
+
 class ParallelBetaDiversityMultiple(ParallelBetaDiversity):
 
     def _get_job_commands(self,
@@ -167,51 +175,53 @@ class ParallelBetaDiversityMultiple(ParallelBetaDiversity):
                           command_suffix='; exit'):
         """Generate beta diversity to split multiple OTU tables to multiple jobs
         """
-    
+
         if params['full_tree']:
             full_tree_str = '-f'
         else:
             full_tree_str = ''
-        
+
         if params['tree_path']:
             tree_str = '-t %s' % params['tree_path']
         else:
             tree_str = ''
-            
+
         commands = []
         result_filepaths = []
-        
+
         metrics = params['metrics']
-        
+
         for input_fp in input_fps:
             input_path, input_fn = split(input_fp)
             input_basename, input_ext = splitext(input_fn)
             output_fns = \
-             ['%s_%s.txt' % (metric, input_basename) for metric in metrics.split(',')]
-            rename_command, current_result_filepaths = self._get_rename_command(\
-             output_fns,working_dir,output_dir)
+                ['%s_%s.txt' % (metric, input_basename)
+                 for metric in metrics.split(',')]
+            rename_command, current_result_filepaths = self._get_rename_command(
+                output_fns, working_dir, output_dir)
             result_filepaths += current_result_filepaths
-        
+
             command = '%s %s -i %s -o %s %s -m %s %s %s %s' %\
-             (command_prefix,
-              self._script_name,
-              input_fp,
-              working_dir,
-              tree_str,
-              params['metrics'],
-              full_tree_str,
-              rename_command,
-              command_suffix)
-          
+                (command_prefix,
+                 self._script_name,
+                 input_fp,
+                 working_dir,
+                 tree_str,
+                 params['metrics'],
+                 full_tree_str,
+                 rename_command,
+                 command_suffix)
+
             commands.append(command)
 
         commands = self._merge_to_n_commands(commands,
                                              params['jobs_to_start'],
                                              command_prefix=command_prefix,
                                              command_suffix=command_suffix)
-        
+
         return commands, result_filepaths
 
+
 def parallel_beta_diversity_process_run_results_f(f):
     """ Handles re-assembling of a distance matrix from component vectors
     """
@@ -221,19 +231,19 @@ def parallel_beta_diversity_process_run_results_f(f):
         dm_components = fields[:-1]
         output_fp = fields[-1]
         # assemble the current dm
-        dm = assemble_distance_matrix(map(open,dm_components))
+        dm = assemble_distance_matrix(map(open, dm_components))
         # and write it to file
-        output_f = open(output_fp,'w')
+        output_f = open(output_fp, 'w')
         output_f.write(dm)
         output_f.close()
-    
+
     return True
 
+
 def assemble_distance_matrix(dm_components):
     """ assemble distance matrix components into a complete dm string
 
     """
-    print "I get called."
     data = {}
     # iterate over compenents
     for c in dm_components:
@@ -250,7 +260,7 @@ def assemble_distance_matrix(dm_components):
                 # otherwise this is a data row so add it to data
                 else:
                     sid = fields[0]
-                    data[sid] = dict(zip(col_ids,fields[1:]))
+                    data[sid] = dict(zip(col_ids, fields[1:]))
 
     # grab the col/row ids as a list so it's ordered
     labels = data.keys()
@@ -258,7 +268,7 @@ def assemble_distance_matrix(dm_components):
     dm = []
     # construct the dm one row at a time
     for l1 in labels:
-        dm.append([data[l1][l2] for l2 in labels])
+        dm.append([float(data[l1][l2]) for l2 in labels])
     # create the dm string and return it
-    dm = format_distance_matrix(labels,dm)
+    dm = format_distance_matrix(labels, dm)
     return dm
