@@ -5,39 +5,42 @@ __author__ = "Jai Ram Rideout"
 __copyright__ = "Copyright 2012, The QIIME project"
 __credits__ = ["Jai Ram Rideout"]
 __license__ = "GPL"
-__version__ = "1.8.0"
+__version__ = "1.9.1"
 __maintainer__ = "Jai Ram Rideout"
 __email__ = "jai.rideout@gmail.com"
 
 from os.path import split
 from shutil import copy
-from cogent.app.formatdb import build_blast_db_from_fasta_path
-from cogent.parse.fasta import MinimalFastaParser
+
+from bfillings.formatdb import build_blast_db_from_fasta_path
+
+from skbio.parse.sequences import parse_fasta
+
 from qiime.identify_chimeric_seqs import make_cidx_file
 from qiime.parse import parse_tmp_to_final_filepath_map_file
 from qiime.util import write_degapped_fasta_to_file
-
 from qiime.parallel.util import ParallelWrapper
 
+
 class ParallelChimericSequenceIdentifier(ParallelWrapper):
     _script_name = 'identify_chimeric_seqs.py'
     _input_splitter = ParallelWrapper._split_fasta
     _job_prefix = 'CHIM'
     _process_run_results_f = \
-         'qiime.parallel.identify_chimeric_seqs.basic_process_run_results_f'
+        'qiime.parallel.identify_chimeric_seqs.basic_process_run_results_f'
 
     def _precommand_initiation(self, input_fp, output_dir, working_dir,
                                params):
         if params['chimera_detection_method'] == 'blast_fragments':
             blast_db, db_files_to_remove = \
-                 build_blast_db_from_fasta_path(params['reference_seqs_fp'],
-                                                output_dir=working_dir)
+                build_blast_db_from_fasta_path(params['reference_seqs_fp'],
+                                               output_dir=working_dir)
             self.files_to_remove += db_files_to_remove
             params['blast_db'] = blast_db
         elif params['chimera_detection_method'] == 'ChimeraSlayer':
-            #copy the reference files to working dir
-            #ChimeraSlayer creates an index file of the ref and
-            #will crash without write permission in the ref seqs dir
+            # copy the reference files to working dir
+            # ChimeraSlayer creates an index file of the ref and
+            # will crash without write permission in the ref seqs dir
             aligned_reference_seqs_fp = params['aligned_reference_seqs_fp']
             _, new_ref_filename = split(aligned_reference_seqs_fp)
             copy(aligned_reference_seqs_fp, working_dir)
@@ -45,33 +48,33 @@ class ParallelChimericSequenceIdentifier(ParallelWrapper):
 
             self.files_to_remove.append(aligned_reference_seqs_fp)
             params['aligned_reference_seqs_fp'] = aligned_reference_seqs_fp
-     
-            #if given, also copy the unaligned ref db
+
+            # if given, also copy the unaligned ref db
             reference_seqs_fp = params['reference_seqs_fp']
             if reference_seqs_fp:
                 _, new_ref_filename = split(reference_seqs_fp)
                 copy(reference_seqs_fp, working_dir)
                 reference_seqs_fp = working_dir + "/" + new_ref_filename
             else:
-                #otherwise create it
+                # otherwise create it
                 reference_seqs_fp = write_degapped_fasta_to_file(
-                        MinimalFastaParser(open(aligned_reference_seqs_fp)),
-                                           tmp_dir=working_dir)
-            #delete it afterwards
+                    parse_fasta(open(aligned_reference_seqs_fp)),
+                    tmp_dir=working_dir)
+            # delete it afterwards
             self.files_to_remove.append(reference_seqs_fp)
             params['reference_seqs_fp'] = reference_seqs_fp
 
-            #build blast db of reference, otherwise ChimeraSlayer will do it
-            #and parallel jobs clash
+            # build blast db of reference, otherwise ChimeraSlayer will do it
+            # and parallel jobs clash
             _, db_files_to_remove = \
-                 build_blast_db_from_fasta_path(reference_seqs_fp)
+                build_blast_db_from_fasta_path(reference_seqs_fp)
             self.files_to_remove += db_files_to_remove
 
-            #make the index file globally
-            #Reason: ChimeraSlayer first checks to see if the index file is
-            #there. If not it tries to create it. This can lead to race
-            #condition if several parallel jobs try to create it at the same
-            #time.
+            # make the index file globally
+            # Reason: ChimeraSlayer first checks to see if the index file is
+            # there. If not it tries to create it. This can lead to race
+            # condition if several parallel jobs try to create it at the same
+            # time.
             make_cidx_file(aligned_reference_seqs_fp)
             self.files_to_remove.append(aligned_reference_seqs_fp + ".cidx")
         else:
@@ -95,8 +98,8 @@ class ParallelChimericSequenceIdentifier(ParallelWrapper):
             # Each run ends with moving the output file from the tmp dir to
             # the output_dir. Build the command to perform the move here.
             rename_command, current_result_filepaths = \
-                    self._get_rename_command([fn % i for fn in out_filenames],
-                                             working_dir, output_dir)
+                self._get_rename_command([fn % i for fn in out_filenames],
+                                         working_dir, output_dir)
             result_filepaths += current_result_filepaths
 
             optional_options = ""
@@ -129,7 +132,7 @@ class ParallelChimericSequenceIdentifier(ParallelWrapper):
                      fasta_fp,
                      params['aligned_reference_seqs_fp'],
                      working_dir + "/" + out_filenames[0] % i,
-                     optional_options,    
+                     optional_options,
                      rename_command,
                      command_suffix)
             else:
@@ -146,23 +149,23 @@ class ParallelChimericSequenceIdentifier(ParallelWrapper):
         """Generate command to initiate a poller to monitior/process completed runs
         """
         result = '%s poller.py -f %s -p %s -m %s -d %s -t %d %s' % \
-         (command_prefix,
-          expected_files_filepath,
-          self._process_run_results_f,
-          merge_map_filepath,
-          deletion_list_filepath,
-          self._seconds_to_sleep,
-          command_suffix)
+            (command_prefix,
+             expected_files_filepath,
+             self._process_run_results_f,
+             merge_map_filepath,
+             deletion_list_filepath,
+             self._seconds_to_sleep,
+             command_suffix)
         return result, []
 
     def _write_merge_map_file(self, input_file_basename, job_result_filepaths,
                               params, output_dir, merge_map_filepath,
                               failures=False):
-        f = open(merge_map_filepath,'w')
+        f = open(merge_map_filepath, 'w')
         out_filepaths = [params['output_fp']]
 
         chims_fps = []
-        logs_fps = [] #logs_fp currently not used
+        logs_fps = []  # logs_fp currently not used
 
         for fp in job_result_filepaths:
             if fp.endswith('_chimeric.txt'):
@@ -178,31 +181,30 @@ class ParallelChimericSequenceIdentifier(ParallelWrapper):
 
 def basic_process_run_results_f(f):
     """ Copy each list of infiles to each outfile and delete infiles
-    
+
         f: file containing one set of mapping instructions per line
-        
+
         example f:
          f1.txt f2.txt f3.txt f_combined.txt
          f1.log f2.log f3.log f_combined.log
-         
-        If f contained the two lines above, this function would 
+
+        If f contained the two lines above, this function would
          concatenate f1.txt, f2.txt, and f3.txt into f_combined.txt
          and f1.log, f2.log, and f3.log into f_combined.log
     """
-    infiles_lists,out_filepaths = parse_tmp_to_final_filepath_map_file(f)
-    for infiles_list, out_filepath in zip(infiles_lists,out_filepaths):
+    infiles_lists, out_filepaths = parse_tmp_to_final_filepath_map_file(f)
+    for infiles_list, out_filepath in zip(infiles_lists, out_filepaths):
         try:
-            of = open(out_filepath,'w')
+            of = open(out_filepath, 'w')
         except IOError:
-            raise IOError,\
-             "Poller can't open final output file: %s" % out_filepath  +\
-             "\nLeaving individual jobs output.\n Do you have write access?"
+            raise IOError("Poller can't open final output file: %s" % out_filepath +
+                          "\nLeaving individual jobs output.\n Do you have write access?")
 
         for fp in infiles_list:
             for line in open(fp):
-               of.write('%s\n' % line.strip('\n'))
+                of.write('%s\n' % line.strip('\n'))
         of.close()
     # It is a good idea to have your clean_up_callback return True.
-    # That way, if you get mixed up and pass it as check_run_complete_callback, 
+    # That way, if you get mixed up and pass it as check_run_complete_callback,
     # you'll get an error right away rather than going into an infinite loop
     return True
