@@ -1,11 +1,11 @@
 #!/usr/bin/env python
-#file trim_sff_primers.py: resets trim values in sff file based on primers.
+# file trim_sff_primers.py: resets trim values in sff file based on primers.
 
 __author__ = "Rob Knight"
 __copyright__ = "Copyright 2011, The QIIME Project"
-__credits__ = ["Rob Knight", 'Kyle Bittinger']
+__credits__ = ["Rob Knight", 'Kyle Bittinger', "Jai Ram Rideout"]
 __license__ = "GPL"
-__version__ = "1.8.0"
+__version__ = "1.9.1"
 __maintainer__ = "Kyle Bittinger"
 __email__ = "kylebittinger@gmail.com"
 
@@ -14,23 +14,24 @@ __email__ = "kylebittinger@gmail.com"
 Replaces the sff files with the trimmed versions.
 """
 
-import itertools
-import os
-import shutil
-import subprocess
-import sys
-import tempfile
+from itertools import imap
+from os import walk, devnull, remove, rename, close
+from os.path import splitext, join, exists
+from shutil import move
+from subprocess import check_call
+from sys import stderr
+from tempfile import mkstemp, TemporaryFile
+
+from burrito.util import ApplicationNotFoundError
+from cogent.parse.binary_sff import parse_binary_sff, write_binary_sff
+from burrito.util import which
 
-from cogent.util.misc import app_path
-from cogent.app.util import ApplicationNotFoundError
 from qiime.parse import parse_mapping_file
-from cogent.parse.binary_sff import (
-    parse_binary_sff, write_binary_sff
-    )
+
 
 def get_technical_lengths(input_map, debug=False):
     """Returns per-sample info on technical lengths.
-    
+
     Note: KEY_SEQ, BARCODE and PRIMER fields are required. The LINKER
     field is optional.
     """
@@ -51,7 +52,7 @@ def get_technical_lengths(input_map, debug=False):
         curr_tech_len = len(fields[key_index]) + len(fields[bc_index]) + \
             len(fields[primer_index])
         if linker_index is not None:
-            curr_tech_len += len(fields[linker_index]) 
+            curr_tech_len += len(fields[linker_index])
         technical_lengths[fields[0]] = curr_tech_len
     if debug:
         print "Technical lengths:"
@@ -62,11 +63,11 @@ def get_technical_lengths(input_map, debug=False):
 def get_per_lib_sff_fps(sff_dir):
     """Return a dict mapping library ID's to SFF filepaths in a directory.
     """
-    for dirpath, dirnames, fnames in os.walk(sff_dir):
+    for dirpath, dirnames, fnames in walk(sff_dir):
         for fname in fnames:
             if fname.endswith('.sff'):
-                libname, _ = os.path.splitext(fname)
-                yield libname, os.path.join(dirpath, fname)
+                libname, _ = splitext(fname)
+                yield libname, join(dirpath, fname)
 
 
 def set_clip_qual_left(sff_data, technical_read_length):
@@ -77,7 +78,7 @@ def set_clip_qual_left(sff_data, technical_read_length):
     """
     # TODO: Move to PyCogent
     header, reads = sff_data
-    
+
     # sfftools use 1-based indexing
     clip_idx = technical_read_length + 1
 
@@ -85,7 +86,7 @@ def set_clip_qual_left(sff_data, technical_read_length):
         read['clip_qual_left'] = clip_idx
         return read
 
-    return header, itertools.imap(adjust_read, reads)
+    return header, imap(adjust_read, reads)
 
 
 def set_sff_trimpoints(sff_dir, technical_lengths):
@@ -97,30 +98,32 @@ def set_sff_trimpoints(sff_dir, technical_lengths):
         except KeyError:
             continue
         sff_data = parse_binary_sff(open(sff_fp), True)
-        clipped_header, clipped_reads = set_clip_qual_left(sff_data, readlength)
-        
-        _, temp_fp = tempfile.mkstemp(dir=sff_dir)
+        clipped_header, clipped_reads = set_clip_qual_left(
+            sff_data, readlength)
+
+        fd, temp_fp = mkstemp(dir=sff_dir)
+        close(fd)
         with open(temp_fp, 'w') as f:
             write_binary_sff(f, clipped_header, clipped_reads)
 
-        shutil.move(temp_fp, sff_fp)
+        move(temp_fp, sff_fp)
 
 
 def set_sff_trimpoints_with_sfftools(
-    sff_dir, technical_lengths, sffinfo_path='sffinfo', sfffile_path='sfffile',
-    debug=False):
+        sff_dir, technical_lengths, sffinfo_path='sffinfo', sfffile_path='sfffile',
+        debug=False):
     """Set trimpoints to end of technical read for all SFF files in directory.
 
     This function essentially provides the reference implementation.
     It uses the official sfftools from Roche to process the SFF files.
     """
-    if not (os.path.exists(sffinfo_path) or app_path(sffinfo_path)):
+    if not (exists(sffinfo_path) or which(sffinfo_path)):
         raise ApplicationNotFoundError(
             'sffinfo executable not found. Is it installed and in your $PATH?')
-    if not (os.path.exists(sfffile_path) or app_path(sfffile_path)):
+    if not (exists(sfffile_path) or which(sfffile_path)):
         raise ApplicationNotFoundError(
             'sfffile executable not found. Is it installed and in your $PATH?')
-    
+
     for lib_id, sff_fp in get_per_lib_sff_fps(sff_dir):
         try:
             readlength = technical_lengths[lib_id]
@@ -130,8 +133,8 @@ def set_sff_trimpoints_with_sfftools(
         sffinfo_args = [sffinfo_path, '-s', sff_fp]
         if debug:
             print "Running sffinfo command %s" % sffinfo_args
-        sffinfo_output_file = tempfile.TemporaryFile()
-        subprocess.check_call(sffinfo_args, stdout=sffinfo_output_file)
+        sffinfo_output_file = TemporaryFile()
+        check_call(sffinfo_args, stdout=sffinfo_output_file)
         sffinfo_output_file.seek(0)
 
         seqlengths = {}
@@ -145,7 +148,7 @@ def set_sff_trimpoints_with_sfftools(
         trim_file = open(trim_fp, 'w')
         for id_, length in seqlengths.items():
             curr_length = int(seqlengths[id_])
-            # Sfftools use 1-based index 
+            # Sfftools use 1-based index
             left_trim = readlength + 1
             # Key sequence not included in FASTA length
             right_trim = curr_length + 4
@@ -153,7 +156,7 @@ def set_sff_trimpoints_with_sfftools(
                 trim_file.write(
                     "%s\t%s\t%s\n" % (id_, left_trim, right_trim))
             else:
-                sys.stderr.write(
+                stderr.write(
                     'Rejected read %s with trim points %s and %s (orig '
                     'length %s)' % (id_, left_trim, curr_length, length))
         trim_file.close()
@@ -163,6 +166,6 @@ def set_sff_trimpoints_with_sfftools(
             sfffile_path, '-t', trim_fp, '-o', trimmed_sff_fp, sff_fp]
         if debug:
             print "Running sfffile command:", sfffile_args
-        subprocess.check_call(sfffile_args, stdout=open(os.devnull, 'w'))
-        os.remove(sff_fp)
-        os.rename(trimmed_sff_fp, sff_fp)
+        check_call(sfffile_args, stdout=open(devnull, 'w'))
+        remove(sff_fp)
+        rename(trimmed_sff_fp, sff_fp)
