@@ -6,7 +6,7 @@ __author__ = "William Van Treuren"
 __copyright__ = "Copyright 2011, The QIIME project"
 __credits__ = ["William Van Treuren", "Greg Caparaso", "Jai Ram Rideout"]
 __license__ = "GPL"
-__version__ = "1.8.0"
+__version__ = "1.9.1"
 __maintainer__ = "William Van Treuren"
 __email__ = "vantreur@colorado.edu"
 
@@ -22,10 +22,11 @@ from qiime.compare_alpha_diversity import (compare_alpha_diversities,
                                            generate_alpha_diversity_boxplots)
 
 script_info = {}
-script_info['brief_description'] = """This script compares alpha diversities based on a two-sample t-test using either parametric or non-parametric (Monte Carlo) methods."""
- 
+script_info[
+    'brief_description'] = """This script compares alpha diversities based on a two-sample t-test using either parametric or non-parametric (Monte Carlo) methods."""
+
 script_info['script_description'] = """
-This script compares the alpha diversity of samples found in a collated alpha 
+This script compares the alpha diversity of samples found in a collated alpha
 diversity file. The comparison is done not between samples, but between groups
 of samples. The groupings are created via the input category passed via
 -c/--category. Any samples which have the same value under the catgory will be
@@ -76,93 +77,98 @@ If the means/standard deviations are None for any treatment group, the likely
 cause is that there is an \'n\\a\' value in the collated_alpha file that was
 passed.
 """
- 
+
 script_info['script_usage'] = []
 
 script_info['script_usage'].append(("Comparing alpha diversities",
-"The following command takes the following input: a mapping file (which "
-"associaties each sample with a number of characteristics), alpha diversity "
-"metric (the results of collate_alpha for an alpha diverity metric, like "
-"PD_whole_tree), depth (the rarefaction depth to use for comparison), "
-"category (the category in the mapping file to determine which samples to "
-"compare to each other), and output filepath (a path to the output file to be created). A "
-"nonparametric two sample t-test is run to compare the alpha diversities "
-"using the default number of Monte Carlo permutations (999).",
-"%prog -i PD_whole_tree.txt -m mapping.txt -c Treatment -d 100 -o Treatment_PD100"))
+                                    "The following command takes the following input: a mapping file (which "
+                                    "associaties each sample with a number of characteristics), alpha diversity "
+                                    "metric (the results of collate_alpha for an alpha diverity metric, like "
+                                    "PD_whole_tree), depth (the rarefaction depth to use for comparison), "
+                                    "category (the category in the mapping file to determine which samples to "
+                                    "compare to each other), and output filepath (a path to the output file to be created). A "
+                                    "nonparametric two sample t-test is run to compare the alpha diversities "
+                                    "using the default number of Monte Carlo permutations (999).",
+                                    "%prog -i PD_whole_tree.txt -m mapping.txt -c Treatment -d 100 -o Treatment_PD100"))
 
 script_info['script_usage'].append(("Comparing alpha diversities",
-"Similar to above, but performs comparisons for two categories.",
-"%prog -i PD_whole_tree.txt -m mapping.txt -c Treatment,DOB -d 100 -o Treatment_DOB_PD100"))
+                                    "Similar to above, but performs comparisons for two categories.",
+                                    "%prog -i PD_whole_tree.txt -m mapping.txt -c Treatment,DOB -d 100 -o Treatment_DOB_PD100"))
 
 script_info['script_usage'].append(("Parametric t-test",
-"The following command runs a parametric two sample t-test using the "
-"t-distribution instead of Monte Carlo permutations at rarefaction depth 100.",
-"%prog -i PD_whole_tree.txt -m mapping.txt -c Treatment -d 100 -o "
-"PD_d100_parametric -t parametric"))
+                                    "The following command runs a parametric two sample t-test using the "
+                                    "t-distribution instead of Monte Carlo permutations at rarefaction depth 100.",
+                                    "%prog -i PD_whole_tree.txt -m mapping.txt -c Treatment -d 100 -o "
+                                    "PD_d100_parametric -t parametric"))
 
 script_info['script_usage'].append(("Parametric t-test",
-"The following command runs a parametric two sample t-test using the "
-"t-distribution instead of Monte Carlo permutations at the greatest depth available.",
-"%prog -i PD_whole_tree.txt -m mapping.txt -c Treatment -o "
-"PD_dmax_parametric -t parametric"))
+                                    "The following command runs a parametric two sample t-test using the "
+                                    "t-distribution instead of Monte Carlo permutations at the greatest depth available.",
+                                    "%prog -i PD_whole_tree.txt -m mapping.txt -c Treatment -o "
+                                    "PD_dmax_parametric -t parametric"))
 
-script_info['output_description']= """
-Generates a tsv stats file and pdf of boxplots for each input category. 
-Each row in the tsv file corresponds to a comparison between two groups of treatment values, 
-and includes the means and standard deviations of the two groups' alpha diversities, 
+script_info['output_description'] = """
+Generates a tsv stats file and pdf of boxplots for each input category.
+Each row in the tsv file corresponds to a comparison between two groups of treatment values,
+and includes the means and standard deviations of the two groups' alpha diversities,
 along with the results of the two-sample t-test.
 """
 
-script_info['script_usage_output_to_remove'] = ['$PWD/PD_dmax_parametric.txt','$PWD/PD_d100_parametric.txt', '$PWD/PD_d100.txt']
+script_info[
+    'script_usage_output_to_remove'] = [
+    '$PWD/PD_dmax_parametric.txt',
+    '$PWD/PD_d100_parametric.txt',
+    '$PWD/PD_d100.txt']
 
-script_info['required_options']=[
- make_option('-i',
-  '--alpha_diversity_fp',
-  action='store',
-  type='existing_filepath',
-  help='path to collated alpha diversity file (as generated by '
-       'collate_alpha.py) [REQUIRED]'),
- make_option('-m',
-  '--mapping_fp',
-  action='store',
-  type='existing_filepath',
-  help='path to the mapping file [REQUIRED]'),
- make_option('-c',
-  '--categories',
-  action='store',
-  type='string',
-  help='comma-separated list of categories for comparison [REQUIRED]'),
- make_option('-o',
-  '--output_dir',
-  action='store',
-  type='new_dirpath',
-  help='directory where output files should be stored [REQUIRED]')]
+script_info['required_options'] = [
+    make_option('-i',
+                '--alpha_diversity_fp',
+                action='store',
+                type='existing_filepath',
+                help='path to collated alpha diversity file (as generated by '
+                'collate_alpha.py) [REQUIRED]'),
+    make_option('-m',
+                '--mapping_fp',
+                action='store',
+                type='existing_filepath',
+                help='path to the mapping file [REQUIRED]'),
+    make_option('-c',
+                '--categories',
+                action='store',
+                type='string',
+                help='comma-separated list of categories for comparison [REQUIRED]'),
+    make_option('-o',
+                '--output_dir',
+                action='store',
+                type='new_dirpath',
+                help='directory where output files should be stored [REQUIRED]')]
 
 script_info['optional_options'] = [
- make_option('-t', '--test_type', type='choice', choices=test_types,
-  help='the type of test to perform when calculating the p-values. Valid '
-       'choices: ' + ', '.join(test_types) + '. If test_type is '
-       'nonparametric, Monte Carlo permutations will be used to determine the '
-       'p-value. If test_type is parametric, the num_permutations option will '
-       'be ignored and the t-distribution will be used instead [default: '
-       '%default]', default='nonparametric'),
- make_option('-n', '--num_permutations', type='int', default=999,
-  help='the number of permutations to perform when calculating the '
-       'p-value. Must be greater than 10. Only applies if test_type is '
-       'nonparametric [default: %default]'),
-  make_option('-p', '--correction_method', type='choice',
-  choices=correction_types, help='method to use for correcting multiple '
-  'comparisons. Available methods are bonferroni, fdr, or none. '
-  '[default: %default]', default='bonferroni'),
-  make_option('-d', '--depth', type='int', default=None,
-  help='depth of rarefaction file to use [default: greatest depth]')]
+    make_option('-t', '--test_type', type='choice', choices=test_types,
+                help='the type of test to perform when calculating the p-values. Valid '
+                'choices: ' + ', '.join(test_types) + '. If test_type is '
+                'nonparametric, Monte Carlo permutations will be used to determine the '
+                'p-value. If test_type is parametric, the num_permutations option will '
+                'be ignored and the t-distribution will be used instead [default: '
+                '%default]', default='nonparametric'),
+    make_option('-n', '--num_permutations', type='int', default=999,
+                help='the number of permutations to perform when calculating the '
+                'p-value. Must be greater than 10. Only applies if test_type is '
+                'nonparametric [default: %default]'),
+    make_option('-p', '--correction_method', type='choice',
+                choices=correction_types, help='method to use for correcting multiple '
+                'comparisons. Available methods are bonferroni, fdr, or none. '
+                '[default: %default]', default='bonferroni'),
+    make_option('-d', '--depth', type='int', default=None,
+                help='depth of rarefaction file to use [default: greatest depth]')]
 
 
 script_info['version'] = __version__
 
+
 def main():
     option_parser, opts, args = parse_command_line_parameters(**script_info)
-    
+
     mapping_fp = opts.mapping_fp
     alpha_diversity_fp = opts.alpha_diversity_fp
     categories = opts.categories.split(',')
@@ -175,21 +181,21 @@ def main():
     if num_permutations < 10:
         option_parser.error('Number of permuations must be greater than or '
                             'equal to 10.')
-    
+
     create_dir(output_dir)
     for category in categories:
-        stat_output_fp = join(output_dir,'%s_stats.txt' % category)
-        boxplot_output_fp = join(output_dir,'%s_boxplots.pdf' % category)
+        stat_output_fp = join(output_dir, '%s_stats.txt' % category)
+        boxplot_output_fp = join(output_dir, '%s_boxplots.pdf' % category)
 
         alpha_diversity_f = open(alpha_diversity_fp, 'U')
         mapping_f = open(mapping_fp, 'U')
         ttest_result, alphadiv_avgs = \
-         compare_alpha_diversities(alpha_diversity_f,
-                                   mapping_f,
-                                   category,
-                                   depth,
-                                   test_type,
-                                   num_permutations)
+            compare_alpha_diversities(alpha_diversity_f,
+                                      mapping_f,
+                                      category,
+                                      depth,
+                                      test_type,
+                                      num_permutations)
         alpha_diversity_f.close()
         mapping_f.close()
 
@@ -202,17 +208,17 @@ def main():
                   'Group2 std\tt stat\tp-value')
         lines = [header]
         for (t0, t1), v in corrected_result.items():
-            lines.append('\t'.join(map(str,[t0,
-                                            t1,
-                                            alphadiv_avgs[t0][0],
-                                            alphadiv_avgs[t0][1],
-                                            alphadiv_avgs[t1][0],
-                                            alphadiv_avgs[t1][1],
-                                            v[0],
-                                            v[1]])))
+            lines.append('\t'.join(map(str, [t0,
+                                             t1,
+                                             alphadiv_avgs[t0][0],
+                                             alphadiv_avgs[t0][1],
+                                             alphadiv_avgs[t1][0],
+                                             alphadiv_avgs[t1][1],
+                                             v[0],
+                                             v[1]])))
         stat_output_f.write('\n'.join(lines) + '\n')
         stat_output_f.close()
-        
+
         # write box plots
         alpha_diversity_f = open(alpha_diversity_fp, 'U')
         mapping_f = open(mapping_fp, 'U')
