@@ -6,10 +6,10 @@ __author__ = "Rob Knight"
 __copyright__ = "Copyright 2011, The QIIME Project"
 __credits__ = ["Rob Knight", "Jens Reeder"]
 __license__ = "GPL"
-__version__ = "1.8.0"
+__version__ = "1.9.1"
 __maintainer__ = "Kyle Bittinger"
 __email__ = "kylebittinger@gmail.com"
- 
+
 
 from qiime.util import parse_command_line_parameters, get_options_lookup
 from qiime.util import make_option
@@ -18,20 +18,20 @@ from qiime.make_fastq import make_fastq_single, make_fastq_multi
 
 options_lookup = get_options_lookup()
 
-script_info={}
-script_info['brief_description']="Make FASTQ file for ERA submission from \
+script_info = {}
+script_info['brief_description'] = "Make FASTQ file for ERA submission from \
 paired FASTA and QUAL files"
-script_info['script_description']="The ERA currently requires a separate \
+script_info['script_description'] = "The ERA currently requires a separate \
 FASTQ file for each library, split by library id. This code takes the output \
 from split_libraries.py and the corresponding QUAL files and produces \
 ERA-compatible FASTQ files."
-script_info['script_usage']=[]
-script_info['script_usage'].append(("Example:","Take input FASTA file \
+script_info['script_usage'] = []
+script_info['script_usage'].append(("Example:", "Take input FASTA file \
 input_fasta_filepath and QUAL file input_qual_filepath: make separate file \
 for each library (with the -s option: assumes that the FASTA file is the \
-output of split_libraries.py or similar script):","%prog -f $PWD/seqs.fna -q \
+output of split_libraries.py or similar script):", "%prog -f $PWD/seqs.fna -q \
 $PWD/Fasting_Example.qual -s"))
-script_info['output_description']="""Matches QUAL info to FASTA entries by id,\
+script_info['output_description'] = """Matches QUAL info to FASTA entries by id,\
  and writes FASTQ output to one file or to per-library files.
 
 The FASTQ format for each record is as follows:
@@ -42,21 +42,22 @@ seq as bases
 qual scores as string of chr(33+qual)
 """
 
-script_info['required_options']=[options_lookup['input_fasta'],\
-    make_option('-q', '--qual', dest='qual_fps',
-        type='existing_filepaths',
-        help='names of QUAL files, comma-delimited'),
-]
-script_info['optional_options']=[
-    make_option('-o','--result_fp', default=None,
-        type='new_filepath', help='Path to store results '
-        '[default: <input_sequences_filename>.fastq]'),
+script_info['required_options'] = [options_lookup['input_fasta'],
+                                   make_option('-q', '--qual', dest='qual_fps',
+                                               type='existing_filepaths',
+                                               help='names of QUAL files, comma-delimited'),
+                                   ]
+script_info['optional_options'] = [
+    make_option('-o', '--result_fp', default=None,
+                type='new_filepath', help='Path to store results '
+                '[default: <input_sequences_filename>.fastq]'),
     make_option('-s', '--split', dest='split', action='store_true',
-        help='make separate file for each library [default:%default]',
-        default=False)
+                help='make separate file for each library [default:%default]',
+                default=False)
 ]
 script_info['version'] = __version__
 
+
 def main():
     option_parser, opts, args = parse_command_line_parameters(**script_info)
 
