@@ -8,16 +8,16 @@ from glob import glob
 import re
 from sys import exit
 from qiime.util import (parse_command_line_parameters, get_options_lookup,
-                       load_qiime_config,qiime_system_call,get_qiime_scripts_dir,
-                       make_option, get_tmp_filename, get_qiime_project_dir)
+                        load_qiime_config, qiime_system_call, get_qiime_scripts_dir,
+                        make_option, get_qiime_project_dir, get_qiime_temp_dir)
 from qiime.test import run_script_usage_tests
 
 __author__ = "Rob Knight"
-__copyright__ = "Copyright 2011, The QIIME Project" #consider project name
-__credits__ = ["Rob Knight","Greg Caporaso", "Jai Ram Rideout",
-    "Yoshiki Vazquez Baeza"] #remember to add yourself if you make changes
+__copyright__ = "Copyright 2011, The QIIME Project"  # consider project name
+__credits__ = ["Rob Knight", "Greg Caporaso", "Jai Ram Rideout",
+               "Yoshiki Vazquez Baeza"]  # remember to add yourself if you make changes
 __license__ = "GPL"
-__version__ = "1.8.0"
+__version__ = "1.9.1"
 __maintainer__ = "Greg Caporaso"
 __email__ = "gregcaporaso@gmail.com"
 
@@ -26,36 +26,38 @@ options_lookup = get_options_lookup()
 script_info = {}
 script_info['brief_description'] = ""
 script_info['script_description'] = ""
-script_info['script_usage'] = [("","","")]
-script_info['output_description']= ""
+script_info['script_usage'] = [("", "", "")]
+script_info['output_description'] = ""
 script_info['required_options'] = []
 script_info['optional_options'] = [
- make_option('--suppress_unit_tests',
-             action='store_true',
-             help='suppress unit tests [default: %default]',
-             default=False),
- make_option('--suppress_script_usage_tests',
-             action='store_true',
-             help='suppress script usage tests [default: %default]',
-             default=False),
- make_option('--unittest_glob',
-             help='wildcard pattern to match tests to run [default: run all]',
-             default=None),
- make_option('--script_usage_tests',
-             help='comma-separated list of tests to run [default: run all]',
-             default=None),
+    make_option('--suppress_unit_tests',
+                action='store_true',
+                help='suppress unit tests [default: %default]',
+                default=False),
+    make_option('--suppress_script_usage_tests',
+                action='store_true',
+                help='suppress script usage tests [default: %default]',
+                default=False),
+    make_option('--unit_test_glob',
+                help='wildcard pattern to match tests to run [default: run all]',
+                default=None),
+    make_option('--script_usage_tests',
+                help='comma-separated list of tests to run [default: run all]',
+                default=None),
 ]
 script_info['version'] = __version__
 script_info['help_on_no_arguments'] = False
 
 qiime_config = load_qiime_config()
 
+
 def main():
     option_parser, opts, args =\
-       parse_command_line_parameters(**script_info)
+        parse_command_line_parameters(**script_info)
 
     if (opts.suppress_unit_tests and opts.suppress_script_usage_tests):
-       option_parser.error("You're suppressing both test types. Nothing to run.")
+        option_parser.error(
+            "You're suppressing both test types. Nothing to run.")
 
     test_dir = abspath(dirname(__file__))
 
@@ -69,13 +71,13 @@ def main():
     # fail unit tests.
     if not opts.suppress_unit_tests:
         unittest_names = []
-        if not opts.unittest_glob:
+        if not opts.unit_test_glob:
             for root, dirs, files in walk(test_dir):
                 for name in files:
                     if name.startswith('test_') and name.endswith('.py'):
-                        unittest_names.append(join(root,name))
+                        unittest_names.append(join(root, name))
         else:
-            for fp in glob(opts.unittest_glob):
+            for fp in glob(opts.unit_test_glob):
                 fn = split(fp)[1]
                 if fn.startswith('test_') and fn.endswith('.py'):
                     unittest_names.append(abspath(fp))
@@ -93,25 +95,24 @@ def main():
                 else:
                     bad_tests.append(unittest_name)
 
-    qiime_test_data_dir = join(get_qiime_project_dir(),'qiime_test_data')
+    qiime_test_data_dir = join(get_qiime_project_dir(), 'qiime_test_data')
     qiime_test_data_dir_exists = exists(qiime_test_data_dir)
     if not opts.suppress_script_usage_tests and qiime_test_data_dir_exists:
-        if opts.script_usage_tests != None:
+        if opts.script_usage_tests is not None:
             script_usage_tests = opts.script_usage_tests.split(',')
         else:
             script_usage_tests = None
 
         # Run the script usage testing functionality
-        script_usage_result_summary, num_script_usage_example_failures = \
-         run_script_usage_tests(
-               test_data_dir=qiime_test_data_dir,
-               scripts_dir=get_qiime_scripts_dir(),
-               working_dir=qiime_config['temp_dir'],
-               verbose=True,
-               tests=script_usage_tests,
-               failure_log_fp=None,
-               force_overwrite=True,
-               timeout=240)
+        script_usage_result_summary, has_script_usage_example_failures = \
+            run_script_usage_tests(
+                test_data_dir=qiime_test_data_dir,
+                scripts_dir=get_qiime_scripts_dir(),
+                working_dir=get_qiime_temp_dir(),
+                verbose=True,
+                tests=script_usage_tests,
+                force_overwrite=True,
+                timeout=400)
 
     print "==============\nResult summary\n=============="
 
@@ -119,19 +120,19 @@ def main():
         print "\nUnit test result summary\n------------------------\n"
         if bad_tests:
             print "\nFailed the following unit tests.\n%s" % '\n'.join(bad_tests)
-    
+
         if missing_application_tests:
-            print "\nFailed the following unit tests, in part or whole due "+\
-            "to missing external applications.\nDepending on the QIIME features "+\
-            "you plan to use, this may not be critical.\n%s"\
-             % '\n'.join(missing_application_tests)
-        
+            print "\nFailed the following unit tests, in part or whole due " +\
+                "to missing external applications.\nDepending on the QIIME features " +\
+                "you plan to use, this may not be critical.\n%s"\
+                % '\n'.join(missing_application_tests)
+
         if not (missing_application_tests or bad_tests):
             print "\nAll unit tests passed.\n\n"
 
     if not opts.suppress_script_usage_tests:
         if qiime_test_data_dir_exists:
-            print "\nScript usage test result summary\n------------------------------------\n"
+            print "\nScript usage test result summary\n--------------------------------\n"
             print script_usage_result_summary
         else:
             print "\nCould not run script usage tests because the directory %s does not exist." % qiime_test_data_dir
@@ -141,14 +142,14 @@ def main():
     # exist and we can't have any failures.
     script_usage_tests_success = (opts.suppress_script_usage_tests or
                                   (qiime_test_data_dir_exists and
-                                   num_script_usage_example_failures == 0))
+                                   not has_script_usage_example_failures))
 
     # If any of the unit tests or script usage tests fail, or if we have any
     # missing application errors, use return code 1 (as python's unittest
     # module does to indicate one or more failures).
     return_code = 1
     if (len(bad_tests) == 0 and len(missing_application_tests) == 0 and
-        script_usage_tests_success):
+            script_usage_tests_success):
         return_code = 0
     return return_code
 
