@@ -6,55 +6,56 @@ __author__ = "Greg Caporaso"
 __copyright__ = "Copyright 2011, The QIIME project"
 __credits__ = ["Greg Caporaso"]
 __license__ = "GPL"
-__version__ = "1.8.0"
+__version__ = "1.9.1"
 __maintainer__ = "Greg Caporaso"
 __email__ = "gregcaporaso@gmail.com"
 
 from shutil import rmtree
 from glob import glob
 from os.path import exists, join
-from cogent.util.unit_test import TestCase, main
-from cogent.util.misc import remove_files, create_dir
+from os import close
+from tempfile import mkstemp, mkdtemp
+
+from skbio.util import remove_files
+from unittest import TestCase, main
 from qiime.parallel.align_seqs import ParallelAlignSeqsPyNast
-from qiime.util import (get_qiime_temp_dir, 
-                        get_tmp_filename,
-                        count_seqs_in_filepaths)
+from qiime.util import get_qiime_temp_dir, count_seqs_in_filepaths
 from qiime.test import initiate_timeout, disable_timeout
 
+
 class ParallelAlignSeqsTests(TestCase):
-    
+
     def setUp(self):
         """ """
         self.files_to_remove = []
         self.dirs_to_remove = []
-        
+
         tmp_dir = get_qiime_temp_dir()
-        self.test_out = get_tmp_filename(tmp_dir=tmp_dir,
-                                         prefix='qiime_parallel_tests_',
-                                         suffix='',
-                                         result_constructor=str)
+        self.test_out = mkdtemp(dir=tmp_dir,
+                                prefix='qiime_parallel_tests_',
+                                suffix='')
         self.dirs_to_remove.append(self.test_out)
-        create_dir(self.test_out)
-        
-        self.template_fp = get_tmp_filename(tmp_dir=self.test_out,
-                                            prefix='qiime_template',
-                                            suffix='.fasta')
-        template_f = open(self.template_fp,'w')
+
+        fd, self.template_fp = mkstemp(dir=self.test_out,
+                                      prefix='qiime_template',
+                                      suffix='.fasta')
+        close(fd)
+        template_f = open(self.template_fp, 'w')
         template_f.write(pynast_test1_template_fasta)
         template_f.close()
         self.files_to_remove.append(self.template_fp)
-        
-        self.inseqs1_fp = get_tmp_filename(tmp_dir=self.test_out,
-                                            prefix='qiime_inseqs',
-                                            suffix='.fasta')
-        inseqs1_f = open(self.inseqs1_fp,'w')
+
+        fd, self.inseqs1_fp = mkstemp(dir=self.test_out,
+                                     prefix='qiime_inseqs',
+                                     suffix='.fasta')
+        close(fd)
+        inseqs1_f = open(self.inseqs1_fp, 'w')
         inseqs1_f.write(inseqs1)
         inseqs1_f.close()
         self.files_to_remove.append(self.inseqs1_fp)
-        
+
         initiate_timeout(60)
 
-    
     def tearDown(self):
         """ """
         disable_timeout()
@@ -65,19 +66,20 @@ class ParallelAlignSeqsTests(TestCase):
             if exists(d):
                 rmtree(d)
 
+
 class ParallelAlignSeqsPyNastTests(ParallelAlignSeqsTests):
 
     def test_parallel_align_seqs_pynast(self):
         """ parallel_align_seqs_pynast functions as expected """
 
         params = {
-         'min_percent_id':0.75,
-         'min_length':15,
-         'template_fp':self.template_fp,
-         'pairwise_alignment_method':'uclust',
-         'blast_db':None
+            'min_percent_id': 0.75,
+            'min_length': 15,
+            'template_fp': self.template_fp,
+            'pairwise_alignment_method': 'uclust',
+            'blast_db': None
         }
-        
+
         app = ParallelAlignSeqsPyNast()
         r = app(self.inseqs1_fp,
                 self.test_out,
@@ -90,9 +92,9 @@ class ParallelAlignSeqsPyNastTests(ParallelAlignSeqsTests):
         num_input_seqs = count_seqs_in_filepaths([self.inseqs1_fp])[1]
         num_template_seqs = count_seqs_in_filepaths([self.template_fp])[1]
         num_output_seqs = \
-         count_seqs_in_filepaths(glob(join(self.test_out,'*fasta')))[1] \
-         - num_input_seqs - num_template_seqs
-        self.assertEqual(num_input_seqs,num_output_seqs)
+            count_seqs_in_filepaths(glob(join(self.test_out, '*fasta')))[1] \
+            - num_input_seqs - num_template_seqs
+        self.assertEqual(num_input_seqs, num_output_seqs)
 
 
 pynast_test1_template_fasta = """>1
@@ -117,4 +119,4 @@ AA
 
 
 if __name__ == "__main__":
-    main()
\ No newline at end of file
+    main()
