@@ -6,73 +6,78 @@ __author__ = "Greg Caporaso"
 __copyright__ = "Copyright 2011, The QIIME project"
 __credits__ = ["Greg Caporaso"]
 __license__ = "GPL"
-__version__ = "1.8.0"
+__version__ = "1.9.1"
 __maintainer__ = "Greg Caporaso"
 __email__ = "gregcaporaso@gmail.com"
 
 from glob import glob
 from shutil import rmtree
+from os import close
 from os.path import exists, join
-from cogent.util.unit_test import TestCase, main
-from cogent.util.misc import create_dir, remove_files
-from biom.parse import parse_biom_table
+from tempfile import mkstemp, mkdtemp
+
+from skbio.util import remove_files
+from unittest import TestCase, main
+from numpy.testing import assert_almost_equal
+from biom import load_table
 from qiime.test import initiate_timeout, disable_timeout
-from qiime.util import get_qiime_temp_dir, get_tmp_filename
+from qiime.util import get_qiime_temp_dir
 from qiime.parse import parse_otu_map
-from qiime.parallel.map_reads_to_reference import \
- (ParallelDatabaseMapperUsearch, ParallelDatabaseMapperBlat,
-  ParallelDatabaseMapperBwaShort)
+from qiime.parallel.map_reads_to_reference import (ParallelDatabaseMapperBlat,
+    ParallelDatabaseMapperUsearch, ParallelDatabaseMapperBwaShort)
+
 
 class ParallelDatabaseMapperTests(TestCase):
-    
+
     def setUp(self):
         """ """
         self.files_to_remove = []
         self.dirs_to_remove = []
-        
+
         tmp_dir = get_qiime_temp_dir()
-        self.test_out = get_tmp_filename(tmp_dir=tmp_dir,
-                                         prefix='qiime_parallel_tests_',
-                                         suffix='',
-                                         result_constructor=str)
+        self.test_out = mkdtemp(dir=tmp_dir,
+                                prefix='qiime_parallel_tests_',
+                                suffix='')
         self.dirs_to_remove.append(self.test_out)
-        create_dir(self.test_out)
-        
-        self.refseqs1_fp = get_tmp_filename(tmp_dir=self.test_out,
-                                            prefix='qiime_refseqs',
-                                            suffix='.fasta')
-        refseqs1_f = open(self.refseqs1_fp,'w')
+
+        fd, self.refseqs1_fp = mkstemp(dir=self.test_out,
+                                      prefix='qiime_refseqs',
+                                      suffix='.fasta')
+        close(fd)
+        refseqs1_f = open(self.refseqs1_fp, 'w')
         refseqs1_f.write(refseqs1)
         refseqs1_f.close()
         self.files_to_remove.append(self.refseqs1_fp)
 
-        self.refseqs2_fp = get_tmp_filename(tmp_dir=self.test_out,
-                                            prefix='qiime_refseqs',
-                                            suffix='.fasta')
-        refseqs2_f = open(self.refseqs2_fp,'w')
+        fd, self.refseqs2_fp = mkstemp(dir=self.test_out,
+                                      prefix='qiime_refseqs',
+                                      suffix='.fasta')
+        close(fd)
+        refseqs2_f = open(self.refseqs2_fp, 'w')
         refseqs2_f.write(refseqs2)
         refseqs2_f.close()
         self.files_to_remove.append(self.refseqs2_fp)
-        
-        self.inseqs1_fp = get_tmp_filename(tmp_dir=self.test_out,
-                                            prefix='qiime_inseqs',
-                                            suffix='.fasta')
-        inseqs1_f = open(self.inseqs1_fp,'w')
+
+        fd, self.inseqs1_fp = mkstemp(dir=self.test_out,
+                                     prefix='qiime_inseqs',
+                                     suffix='.fasta')
+        close(fd)
+        inseqs1_f = open(self.inseqs1_fp, 'w')
         inseqs1_f.write(inseqs1)
         inseqs1_f.close()
         self.files_to_remove.append(self.inseqs1_fp)
 
-        self.inseqs2_fp = get_tmp_filename(tmp_dir=self.test_out,
-                                            prefix='qiime_inseqs',
-                                            suffix='.fasta')
-        inseqs2_f = open(self.inseqs2_fp,'w')
+        fd, self.inseqs2_fp = mkstemp(dir=self.test_out,
+                                     prefix='qiime_inseqs',
+                                     suffix='.fasta')
+        close(fd)
+        inseqs2_f = open(self.inseqs2_fp, 'w')
         inseqs2_f.write(inseqs2)
         inseqs2_f.close()
         self.files_to_remove.append(self.inseqs2_fp)
 
         initiate_timeout(60)
 
-    
     def tearDown(self):
         """ """
         disable_timeout()
@@ -83,21 +88,22 @@ class ParallelDatabaseMapperTests(TestCase):
             if exists(d):
                 rmtree(d)
 
+
 class ParallelDatabaseMapperUsearchTests(ParallelDatabaseMapperTests):
 
     def test_parallel_database_mapper_usearch(self):
         """ parallel_database_mapper_usearch functions as expected """
-        
-        params = {'refseqs_fp':self.refseqs1_fp,
-          'min_percent_id':0.97,
-          'evalue':1e-10,
-          'max_accepts':1,
-          'max_rejects':32,
-          'queryalnfract':0.35,
-          'targetalnfract':0.0,
-          'observation_metadata_fp':None
-        }
-        
+
+        params = {'refseqs_fp': self.refseqs1_fp,
+                  'min_percent_id': 0.97,
+                  'evalue': 1e-10,
+                  'max_accepts': 1,
+                  'max_rejects': 32,
+                  'queryalnfract': 0.35,
+                  'targetalnfract': 0.0,
+                  'observation_metadata_fp': None
+                  }
+
         app = ParallelDatabaseMapperUsearch()
         r = app(self.inseqs1_fp,
                 self.test_out,
@@ -105,27 +111,33 @@ class ParallelDatabaseMapperUsearchTests(ParallelDatabaseMapperTests):
                 job_prefix='PTEST',
                 poll_directly=True,
                 suppress_submit_jobs=False)
-        observation_map_fp = glob(join(self.test_out,'observation_map.txt'))[0]
-        omap = parse_otu_map(open(observation_map_fp,'U'))
-        self.assertEqual(len(omap[0]),3)
-        self.assertEqualItems(omap[1],['eco:b0015', 'eco:b0122','eco:b0015:duplicate'])
-        self.assertEqualItems(omap[2],['eco:b0015-pr', 'eco:b0122-pr'])
+        observation_map_fp = glob(
+            join(self.test_out, 'observation_map.txt'))[0]
+        omap = parse_otu_map(open(observation_map_fp, 'U'))
+        self.assertEqual(len(omap[0]), 3)
+        self.assertItemsEqual(
+            omap[1],
+            ['eco:b0015',
+             'eco:b0122',
+             'eco:b0015:duplicate'])
+        self.assertItemsEqual(omap[2], ['eco:b0015-pr', 'eco:b0122-pr'])
+
 
 class ParallelDatabaseMapperBlatTests(ParallelDatabaseMapperTests):
 
     def test_parallel_database_mapper_blat(self):
         """ parallel_database_mapper_blat functions as expected """
-        
-        params = {'refseqs_fp':self.refseqs1_fp,
-          'min_percent_id':0.97,
-          'evalue':1e-10,
-          'max_accepts':1,
-          'max_rejects':32,
-          'queryalnfract':0.35,
-          'targetalnfract':0.0,
-          'observation_metadata_fp':None
-        }
-        
+
+        params = {'refseqs_fp': self.refseqs1_fp,
+                  'min_percent_id': 0.97,
+                  'evalue': 1e-10,
+                  'max_accepts': 1,
+                  'max_rejects': 32,
+                  'queryalnfract': 0.35,
+                  'targetalnfract': 0.0,
+                  'observation_metadata_fp': None
+                  }
+
         app = ParallelDatabaseMapperBlat()
         r = app(self.inseqs1_fp,
                 self.test_out,
@@ -133,51 +145,64 @@ class ParallelDatabaseMapperBlatTests(ParallelDatabaseMapperTests):
                 job_prefix='PTEST',
                 poll_directly=True,
                 suppress_submit_jobs=False)
-        observation_map_fp = glob(join(self.test_out,'observation_map.txt'))[0]
-        omap = parse_otu_map(open(observation_map_fp,'U'))
-        self.assertEqual(len(omap[0]),3)
-        self.assertEqualItems(omap[1],['eco:b0015', 'eco:b0122','eco:b0015:duplicate'])
-        self.assertEqualItems(omap[2],['eco:b0015-pr', 'eco:b0122-pr'])
+        observation_map_fp = glob(
+            join(self.test_out, 'observation_map.txt'))[0]
+        omap = parse_otu_map(open(observation_map_fp, 'U'))
+        self.assertEqual(len(omap[0]), 3)
+        self.assertItemsEqual(
+            omap[1],
+            ['eco:b0015',
+             'eco:b0122',
+             'eco:b0015:duplicate'])
+        self.assertItemsEqual(omap[2], ['eco:b0015-pr', 'eco:b0122-pr'])
+
 
 class ParallelDatabaseMapperBwaShortTests(ParallelDatabaseMapperTests):
-    
+
     def test_bwa_short_database_mapper(self):
         """bwa_short_database_mapper functions as expected """
-        params = {'refseqs_fp':self.refseqs2_fp,
-                  'max_diff':None,
-                  'observation_metadata_fp':None}
+        params = {'refseqs_fp': self.refseqs2_fp,
+                  'max_diff': None,
+                  'observation_metadata_fp': None}
         app = ParallelDatabaseMapperBwaShort()
         r = app(self.inseqs2_fp,
                 self.test_out,
                 params,
                 poll_directly=True,
                 suppress_submit_jobs=False)
-        observation_map_fp = join(self.test_out,'observation_map.txt')
+        observation_map_fp = join(self.test_out, 'observation_map.txt')
         self.assertTrue(exists(observation_map_fp))
-        observation_table_fp = join(self.test_out,'observation_table.biom')
-        table = parse_biom_table(open(observation_table_fp,'U'))
-        self.assertEqualItems(table.SampleIds,['s2','s1'])
-        self.assertEqualItems(table.ObservationIds,['r1','r2','r3','r4','r5'])
-        self.assertEqual(table.sum(),6)
+        observation_table_fp = join(self.test_out, 'observation_table.biom')
+        table = load_table(observation_table_fp)
+        self.assertItemsEqual(table.ids(), ['s2', 's1'])
+        self.assertItemsEqual(
+            table.ids(axis='observation'),
+            ['r1',
+             'r2',
+             'r3',
+             'r4',
+             'r5'])
+        self.assertEqual(table.sum(), 6)
 
     def test_bwa_short_database_mapper_alt_params(self):
         """bwa_short_database_mapper functions as expected """
-        params = {'refseqs_fp':self.refseqs2_fp,
-                  'max_diff':1,
-                  'observation_metadata_fp':None}
+        params = {'refseqs_fp': self.refseqs2_fp,
+                  'max_diff': 1,
+                  'observation_metadata_fp': None}
         app = ParallelDatabaseMapperBwaShort()
         r = app(self.inseqs2_fp,
                 self.test_out,
                 params,
                 poll_directly=True,
                 suppress_submit_jobs=False)
-        observation_map_fp = join(self.test_out,'observation_map.txt')
+        observation_map_fp = join(self.test_out, 'observation_map.txt')
         self.assertTrue(exists(observation_map_fp))
-        observation_table_fp = join(self.test_out,'observation_table.biom')
-        table = parse_biom_table(open(observation_table_fp,'U'))
-        self.assertEqualItems(table.SampleIds,['s2','s1'])
-        self.assertEqualItems(table.ObservationIds,['r2','r3','r4','r5'])
-        self.assertEqual(table.sum(),5)
+        observation_table_fp = join(self.test_out, 'observation_table.biom')
+        table = load_table(observation_table_fp)
+        self.assertItemsEqual(table.ids(), ['s2', 's1'])
+        self.assertItemsEqual(table.ids(axis='observation'),
+                              ['r2', 'r3', 'r4', 'r5'])
+        self.assertEqual(table.sum(), 5)
 
 refseqs1 = """>eco:b0001-pr
 MKRISTTITTTITITTGNGAG
@@ -385,4 +410,4 @@ aagagcttctttgatggtgtgaagaagttttttgacgacctgacccgctaa
 """
 
 if __name__ == "__main__":
-    main()
\ No newline at end of file
+    main()
